@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2022 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2016-2025 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -7,10 +7,13 @@
 #include <config.h>
 #include <agent/ca_cfg_mgr.h>
 #include <agent/parser_context.h>
+#include <config/unix_command_config.h>
 #include <exceptions/exceptions.h>
 #include <process/testutils/d_test_stubs.h>
 #include <process/d_cfg_mgr.h>
 #include <http/basic_auth_config.h>
+#include <hooks/hooks_parser.h>
+#include <util/filesystem.h>
 #include <agent/tests/test_callout_libraries.h>
 #include <agent/tests/test_data_files_config.h>
 #include <boost/pointer_cast.hpp>
@@ -22,6 +25,8 @@ using namespace isc::data;
 using namespace isc::hooks;
 using namespace isc::http;
 using namespace isc::process;
+using namespace isc::config;
+using namespace isc::util;
 
 namespace  {
 
@@ -238,8 +243,8 @@ TEST(CtrlAgentCfgMgr, contextAuthConfigFile) {
 
     auth->setRealm("foobar");
     auth->setDirectory("/tmp");
-    auth->add("", "/tmp/foo", "", "/tmp/bar");
-    auth->add("", "/tmp/test", "", "/tmp/pwd");
+    auth->add("", "foo", "", "bar");
+    auth->add("", "test", "", "pwd");
 
     const HttpAuthConfigPtr& stored_auth = ctx.getAuthConfig();
     ASSERT_TRUE(stored_auth);
@@ -264,7 +269,7 @@ const char* AGENT_CONFIGS[] = {
     "    \"http-port\": 8001,\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
-    "            \"socket-name\": \"/tmp/socket-v4\"\n"
+    "            \"socket-name\": \"socket-v4\"\n"
     "        }\n"
     "    }\n"
     "}",
@@ -275,13 +280,13 @@ const char* AGENT_CONFIGS[] = {
     "    \"http-port\": 8001,\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
-    "            \"socket-name\": \"/tmp/socket-v4\"\n"
+    "            \"socket-name\": \"socket-v4\"\n"
     "        },\n"
     "        \"dhcp6\": {\n"
-    "            \"socket-name\": \"/tmp/socket-v6\"\n"
+    "            \"socket-name\": \"socket-v6\"\n"
     "        },\n"
     "        \"d2\": {\n"
-    "            \"socket-name\": \"/tmp/socket-d2\"\n"
+    "            \"socket-name\": \"socket-d2\"\n"
     "        }\n"
     "   }\n"
     "}",
@@ -294,7 +299,7 @@ const char* AGENT_CONFIGS[] = {
     "    \"http-port\": 8001,\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
-    "            \"socket-name\": \"/tmp/socket-v4\"\n"
+    "            \"socket-name\": \"socket-v4\"\n"
     "        }\n"
     "   },\n"
     "    \"hooks-libraries\": ["
@@ -313,7 +318,7 @@ const char* AGENT_CONFIGS[] = {
     "    \"http-port\": 8001,\n"
     "    \"control-sockets\": {\n"
     "        \"d2\": {\n"
-    "            \"socket-name\": \"/tmp/socket-d2\"\n"
+    "            \"socket-name\": \"socket-d2\"\n"
     "        }\n"
     "    }\n"
     "}",
@@ -324,7 +329,7 @@ const char* AGENT_CONFIGS[] = {
     "    \"http-port\": 8001,\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp6\": {\n"
-    "            \"socket-name\": \"/tmp/socket-v6\"\n"
+    "            \"socket-name\": \"socket-v6\"\n"
     "        }\n"
     "    }\n"
     "}",
@@ -348,7 +353,7 @@ const char* AGENT_CONFIGS[] = {
     "    },\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
-    "            \"socket-name\": \"/tmp/socket-v4\"\n"
+    "            \"socket-name\": \"socket-v4\"\n"
     "        }\n"
     "    }\n"
     "}",
@@ -376,10 +381,10 @@ const char* AGENT_CONFIGS[] = {
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
     "            \"comment\": \"dhcp4 socket\",\n"
-    "            \"socket-name\": \"/tmp/socket-v4\"\n"
+    "            \"socket-name\": \"socket-v4\"\n"
     "        },\n"
     "        \"dhcp6\": {\n"
-    "            \"socket-name\": \"/tmp/socket-v6\",\n"
+    "            \"socket-name\": \"socket-v6\",\n"
     "            \"user-context\": { \"version\": 1 }\n"
     "        }\n"
     "    }\n"
@@ -414,7 +419,7 @@ const char* AGENT_CONFIGS[] = {
     "    },\n"
     "    \"control-sockets\": {\n"
     "        \"dhcp4\": {\n"
-    "            \"socket-name\": \"/tmp/socket-v4\"\n"
+    "            \"socket-name\": \"socket-v4\"\n"
     "        }\n"
     "    }\n"
     "}"
@@ -423,6 +428,44 @@ const char* AGENT_CONFIGS[] = {
 /// @brief Class used for testing CfgMgr
 class AgentParserTest : public isc::process::ConfigParseTest {
 public:
+    /// @brief Constructor.
+    AgentParserTest() {
+        resetHooksPath();
+        setSocketTestPath();
+    }
+
+    /// @brief Destructor.
+    virtual ~AgentParserTest() {
+        resetHooksPath();
+        resetSocketPath();
+    }
+
+    /// @brief Sets the Hooks path from which hooks can be loaded.
+    /// @param explicit_path path to use as the hooks path.
+    void setHooksTestPath(const std::string explicit_path = "") {
+        HooksLibrariesParser::getHooksPath(true,
+                                           (!explicit_path.empty() ?
+                                            explicit_path : CA_HOOKS_TEST_PATH));
+    }
+
+    /// @brief Resets the hooks path to DEFAULT_HOOKS_PATH.
+    void resetHooksPath() {
+        HooksLibrariesParser::getHooksPath(true);
+    }
+
+    /// @brief Sets the path in which the socket can be created.
+    /// @param explicit_path path to use as the socket path.
+    void setSocketTestPath(const std::string explicit_path = "") {
+        auto path = UnixCommandConfig::getSocketPath(true, (!explicit_path.empty() ?
+                                                     explicit_path : TEST_DATA_BUILDDIR));
+        UnixCommandConfig::setSocketPathPerms(file::getPermissions(path));
+    }
+
+    /// @brief Resets the socket path to the default.
+    void resetSocketPath() {
+        UnixCommandConfig::getSocketPath(true);
+        UnixCommandConfig::setSocketPathPerms();
+    }
 
     /// @brief Tries to load input text as a configuration
     ///
@@ -447,6 +490,20 @@ public:
         return (txt);
     }
 
+    /// @brief Make expected contents of socket info with socket path added.
+    ///
+    /// @param name name of the socket
+    /// @return expected string
+    std::string makeSocketStr(const std::string& name) {
+        std::ostringstream os;
+        os << "{ \"socket-name\": \""
+           << name << "\", \"socket-type\": \"unix\","
+           << " \"validated-socket-name\": \""
+           << UnixCommandConfig::getSocketPath() << "/" << name
+           << "\" }";
+        return (os.str());
+    }
+
     /// Configuration Manager (used in tests)
     NakedAgentCfgMgr cfg_mgr_;
 };
@@ -480,8 +537,7 @@ TEST_F(AgentParserTest, configParseSocketDhcp4) {
     ASSERT_TRUE(ctx);
     ConstElementPtr socket = ctx->getControlSocketInfo("dhcp4");
     ASSERT_TRUE(socket);
-    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-v4\", \"socket-type\": \"unix\" }",
-              socket->str());
+    EXPECT_EQ(makeSocketStr("socket-v4"), socket->str());
     EXPECT_FALSE(ctx->getControlSocketInfo("dhcp6"));
     EXPECT_FALSE(ctx->getControlSocketInfo("d2"));
 }
@@ -496,9 +552,7 @@ TEST_F(AgentParserTest, configParseSocketD2) {
     ASSERT_TRUE(ctx);
     ConstElementPtr socket = ctx->getControlSocketInfo("d2");
     ASSERT_TRUE(socket);
-    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-d2\", \"socket-type\": \"unix\" }",
-              socket->str());
-
+    EXPECT_EQ(makeSocketStr("socket-d2"), socket->str());
     EXPECT_FALSE(ctx->getControlSocketInfo("dhcp4"));
     EXPECT_FALSE(ctx->getControlSocketInfo("dhcp6"));
 }
@@ -513,8 +567,7 @@ TEST_F(AgentParserTest, configParseSocketDhcp6) {
     ASSERT_TRUE(ctx);
     ConstElementPtr socket = ctx->getControlSocketInfo("dhcp6");
     ASSERT_TRUE(socket);
-    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-v6\", \"socket-type\": \"unix\" }",
-              socket->str());
+    EXPECT_EQ(makeSocketStr("socket-v6"), socket->str());
     EXPECT_FALSE(ctx->getControlSocketInfo("dhcp4"));
     EXPECT_FALSE(ctx->getControlSocketInfo("d2"));
 }
@@ -529,14 +582,11 @@ TEST_F(AgentParserTest, configParse3Sockets) {
     ConstElementPtr socket4 = ctx->getControlSocketInfo("dhcp4");
     ConstElementPtr socket6 = ctx->getControlSocketInfo("dhcp6");
     ASSERT_TRUE(socket2);
-    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-d2\", \"socket-type\": \"unix\" }",
-              socket2->str());
+    EXPECT_EQ(makeSocketStr("socket-d2"), socket2->str());
     ASSERT_TRUE(socket4);
-    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-v4\", \"socket-type\": \"unix\" }",
-              socket4->str());
+    EXPECT_EQ(makeSocketStr("socket-v4"), socket4->str());
     ASSERT_TRUE(socket6);
-    EXPECT_EQ("{ \"socket-name\": \"/tmp/socket-v6\", \"socket-type\": \"unix\" }",
-              socket6->str());
+    EXPECT_EQ(makeSocketStr("socket-v6"), socket6->str());
 }
 
 // This test checks that the config file with hook library specified can be
@@ -544,6 +594,8 @@ TEST_F(AgentParserTest, configParse3Sockets) {
 // name. In particular, it checks if such a library exists. Therefore we
 // can't use AGENT_CONFIGS[4] as is, but need to run it through path replacer.
 TEST_F(AgentParserTest, configParseHooks) {
+    setHooksTestPath();
+
     // Create the configuration with proper lib path.
     std::string cfg = pathReplacer(AGENT_CONFIGS[4], CALLOUT_LIBRARY);
     // The configuration should be successful.
