@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2015,2017 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -9,7 +9,7 @@
 
 /// @file nc_remove.h This file defines the class NameRemoveTransaction.
 
-#include <d2/nc_trans.h>
+#include <d2srv/nc_trans.h>
 
 namespace isc {
 namespace d2 {
