@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -25,10 +25,10 @@ const int SimpleRemoveTransaction::REMOVING_REV_PTRS_ST;
 
 SimpleRemoveTransaction::
 SimpleRemoveTransaction(asiolink::IOServicePtr& io_service,
-                   dhcp_ddns::NameChangeRequestPtr& ncr,
-                   DdnsDomainPtr& forward_domain,
-                   DdnsDomainPtr& reverse_domain,
-                   D2CfgMgrPtr& cfg_mgr)
+                        dhcp_ddns::NameChangeRequestPtr& ncr,
+                        DdnsDomainPtr& forward_domain,
+                        DdnsDomainPtr& reverse_domain,
+                        D2CfgMgrPtr& cfg_mgr)
     : NameChangeTransaction(io_service, ncr, forward_domain, reverse_domain,
                             cfg_mgr) {
     if (ncr->getChangeType() != isc::dhcp_ddns::CHG_REMOVE) {
@@ -160,8 +160,7 @@ SimpleRemoveTransaction::selectingFwdServerHandler() {
     if (selectNextServer()) {
         // We have a server to try.
         transition(REMOVING_FWD_RRS_ST, SERVER_SELECTED_EVT);
-    }
-    else {
+    } else {
         // Server list is exhausted, so fail the transaction.
         transition(PROCESS_TRANS_FAILED_ST, NO_MORE_SERVERS_EVT);
     }
@@ -235,11 +234,19 @@ SimpleRemoveTransaction::removingFwdRRsHandler() {
         }
 
         case DNSClient::TIMEOUT:
+            // No response from the server, log it and set up
+            // to select the next server for a retry.
+            LOG_ERROR(d2_to_dns_logger, DHCP_DDNS_FORWARD_REMOVE_RRS_TIMEOUT)
+                      .arg(getRequestId())
+                      .arg(getNcr()->getFqdn())
+                      .arg(getCurrentServer()->toText());
+
+            retryTransition(SELECTING_FWD_SERVER_ST);
+            break;
+
         case DNSClient::OTHER:
             // We couldn't send to the current server, log it and set up
             // to select the next server for a retry.
-            // @note For now we treat OTHER as an IO error like TIMEOUT. It
-            // is not entirely clear if this is accurate.
             LOG_ERROR(d2_to_dns_logger, DHCP_DDNS_FORWARD_REMOVE_RRS_IO_ERROR)
                       .arg(getRequestId())
                       .arg(getNcr()->getFqdn())
@@ -305,8 +312,7 @@ SimpleRemoveTransaction::selectingRevServerHandler() {
     if (selectNextServer()) {
         // We have a server to try.
         transition(REMOVING_REV_PTRS_ST, SERVER_SELECTED_EVT);
-    }
-    else {
+    } else {
         // Server list is exhausted, so fail the transaction.
         transition(PROCESS_TRANS_FAILED_ST, NO_MORE_SERVERS_EVT);
     }
@@ -372,11 +378,22 @@ SimpleRemoveTransaction::removingRevPtrsHandler() {
         }
 
         case DNSClient::TIMEOUT:
+            // No response from the server, log it and set up
+            // to select the next server for a retry.
+            LOG_ERROR(d2_to_dns_logger, DHCP_DDNS_REVERSE_REMOVE_TIMEOUT)
+                      .arg(getRequestId())
+                      .arg(getNcr()->getFqdn())
+                      .arg(getCurrentServer()->toText());
+
+            // If we are out of retries on this server, we go back and start
+            // all over on a new server.
+            retryTransition(SELECTING_REV_SERVER_ST);
+            break;
+
+
         case DNSClient::OTHER:
             // We couldn't send to the current server, log it and set up
             // to select the next server for a retry.
-            // @note For now we treat OTHER as an IO error like TIMEOUT. It
-            // is not entirely clear if this is accurate.
             LOG_ERROR(d2_to_dns_logger, DHCP_DDNS_REVERSE_REMOVE_IO_ERROR)
                       .arg(getRequestId())
                       .arg(getNcr()->getFqdn())
