@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2024 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2025 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -14,6 +14,7 @@
 #include <d2/tests/test_configured_libraries.h>
 #include <dhcp_ddns/ncr_io.h>
 #include <hooks/hooks_manager.h>
+#include <hooks/hooks_parser.h>
 #include <process/testutils/d_test_stubs.h>
 
 #include <boost/date_time/posix_time/posix_time.hpp>
@@ -67,12 +68,27 @@ public:
     D2ProcessTest() :
         D2Process("d2test",
                   asiolink::IOServicePtr(new isc::asiolink::IOService())) {
+        resetHooksPath();
         HooksManager::setTestMode(false);
         D2Controller::instance();
     }
 
     /// @brief Destructor
     virtual ~D2ProcessTest() {
+        resetHooksPath();
+    }
+
+    /// @brief Sets the Hooks path from which hooks can be loaded.
+    /// @param explicit_path path to use as the hooks path.
+    void setHooksTestPath(const std::string explicit_path = "") {
+        HooksLibrariesParser::getHooksPath(true,
+                                           (!explicit_path.empty() ?
+                                            explicit_path : D2_HOOKS_TEST_PATH));
+    }
+
+    /// @brief Resets the hooks path to DEFAULT_HOOKS_PATH.
+    void resetHooksPath() {
+        HooksLibrariesParser::getHooksPath(true);
     }
 
     /// @brief Callback that will invoke shutdown method.
@@ -630,7 +646,7 @@ TEST_F(D2ProcessTest, notLoopbackTest) {
     // Note we don't care nor can we predict if this
     // succeeds or fails. The address and port may or may
     // not be valid on the test host.
-    runWithConfig(config);
+    static_cast<void>(runWithConfig(config));
 }
 
 /// @brief Used to permit visual inspection of logs to ensure
@@ -661,6 +677,7 @@ TEST_F(D2ProcessTest, v6LoopbackTest) {
 
 /// @brief Check the configured callout (positive case).
 TEST_F(D2ProcessTest, configuredNoFail) {
+    setHooksTestPath();
     const char* config = "{\n"
         "\"hooks-libraries\": [ {\n"
         " \"library\": \"%LIBRARY%\",\n"
@@ -680,6 +697,7 @@ TEST_F(D2ProcessTest, configuredNoFail) {
 
 /// @brief Check the configured callout (negative case).
 TEST_F(D2ProcessTest, configuredFail) {
+    setHooksTestPath();
     const char* config = "{\n"
         "\"user-context\": { \"error\": \"Fail!\" },\n"
         "\"hooks-libraries\": [ {\n"
