@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -58,8 +58,8 @@ dhcp4_srv_configured(CalloutHandle& handle) {
 
     // Append argument names.
     std::vector<std::string> args = handle.getArgumentNames();
-    for (auto arg = args.begin(); arg != args.end(); ++arg) {
-        if (appendArgument(SRV_CONFIG_MARKER_FILE, arg->c_str()) != 0) {
+    for (auto const& arg : args) {
+        if (appendArgument(SRV_CONFIG_MARKER_FILE, arg.c_str()) != 0) {
             return (1);
         }
     }
