@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2022 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2016-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -7,7 +7,7 @@
 #include <config.h>
 #include <asiolink/io_address.h>
 #include <dhcp/dhcp4.h>
-#include <dhcp/tests/iface_mgr_test_config.h>
+#include <dhcp/testutils/iface_mgr_test_config.h>
 #include <dhcp4/tests/dhcp4_client.h>
 #include <dhcp/option_int.h>
 #include <stats/stats_mgr.h>
@@ -521,7 +521,6 @@ public:
     IfaceMgrTestConfig iface_mgr_test_config_;
 };
 
-
 // This test checks that an incoming DISCOVER that does not match any classes
 // will get the fixed fields empty.
 TEST_F(ClassifyTest, fixedFieldsDiscoverNoClasses) {
@@ -538,7 +537,6 @@ TEST_F(ClassifyTest, fixedFieldsInformNoClasses) {
     testFixedFields(CONFIGS[0], DHCPINFORM, OptionPtr(), "0.0.0.0", "", "");
 }
 
-
 // This test checks that an incoming DISCOVER that does match a class that has
 // next-server specified will result in a response that has the next-server set.
 TEST_F(ClassifyTest, fixedFieldsDiscoverNextServer) {
@@ -561,7 +559,6 @@ TEST_F(ClassifyTest, fixedFieldsInformNextServer) {
     testFixedFields(CONFIGS[0], DHCPINFORM, pxe, "1.2.3.4", "", "");
 }
 
-
 // This test checks that an incoming DISCOVER that does match a class that has
 // server-hostname specified will result in a response that has the sname field set.
 TEST_F(ClassifyTest, fixedFieldsDiscoverHostname) {
@@ -584,7 +581,6 @@ TEST_F(ClassifyTest, fixedFieldsInformHostname) {
     testFixedFields(CONFIGS[0], DHCPINFORM, pxe, "0.0.0.0", "deneb", "");
 }
 
-
 // This test checks that an incoming DISCOVER that does match a class that has
 // boot-file-name specified will result in a response that has the filename field set.
 TEST_F(ClassifyTest, fixedFieldsDiscoverFile1) {
@@ -607,7 +603,6 @@ TEST_F(ClassifyTest, fixedFieldsInformFile1) {
     testFixedFields(CONFIGS[0], DHCPDISCOVER, pxe, "0.0.0.0", "", "pxelinux.0");
 }
 
-
 // This test checks that an incoming DISCOVER that does match a different class that has
 // boot-file-name specified will result in a response that has the filename field set.
 TEST_F(ClassifyTest, fixedFieldsDiscoverFile2) {
@@ -703,7 +698,6 @@ TEST_F(ClassifyTest, fixedFieldsInformNoClasses2) {
     testFixedFields(CONFIGS[2], DHCPINFORM, OptionPtr(), "0.0.0.0", "", "");
 }
 
-
 // This test checks that an incoming DISCOVER that does match a class that has
 // next-server specified will result in a response that has the next-server set.
 TEST_F(ClassifyTest, fixedFieldsDiscoverNextServer2) {
@@ -726,7 +720,6 @@ TEST_F(ClassifyTest, fixedFieldsInformNextServer2) {
     testFixedFields(CONFIGS[2], DHCPINFORM, pxe, "1.2.3.4", "", "");
 }
 
-
 // This test checks that an incoming DISCOVER that does match a class that has
 // boot-file-name specified will result in a response that has the filename field set.
 TEST_F(ClassifyTest, fixedFieldsDiscoverFile21) {
@@ -749,7 +742,6 @@ TEST_F(ClassifyTest, fixedFieldsInformFile21) {
     testFixedFields(CONFIGS[2], DHCPDISCOVER, pxe, "0.0.0.0", "", "pxelinux.0");
 }
 
-
 // This test checks that an incoming DISCOVER that does match a different class that has
 // boot-file-name specified will result in a response that has the filename field set.
 TEST_F(ClassifyTest, fixedFieldsDiscoverFile22) {
@@ -800,7 +792,6 @@ TEST_F(ClassifyTest, fixedFieldsInformNextServer3) {
     testFixedFields(CONFIGS[3], DHCPINFORM, pxe, "0.0.0.0", "", "");
 }
 
-
 // Class pxe2 is only-if-required but the subnet requires its evaluation
 TEST_F(ClassifyTest, fixedFieldsDiscoverHostname3) {
     OptionPtr pxe(new OptionInt<uint16_t>(Option::V4, 93, 0x0007));
