@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2025 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -219,7 +219,7 @@ DirectClientTest::createClientMessage(const Pkt4Ptr& msg,
     // local and remote address are set like it was a message sent from the
     // directly connected client.
     Pkt4Ptr received;
-    createPacketFromBuffer(msg, received);
+    static_cast<void>(createPacketFromBuffer(msg, received));
     received->setIface(iface);
     received->setIndex(ifindex);
     received->setLocalAddr(IOAddress("255.255.255.255"));
