@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2025 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -176,7 +176,7 @@ typedef boost::shared_ptr<TestCBControlDHCPv4> TestCBControlDHCPv4Ptr;
 ///
 /// Exposes internal fields and installs stub implementation of the
 /// @c CBControlDHCPv4 object.
-class NakedControlledDhcpv4Srv: public ControlledDhcpv4Srv {
+class NakedControlledDhcpv4Srv : public ControlledDhcpv4Srv {
 public:
 
     /// @brief Constructor.
@@ -188,7 +188,7 @@ public:
     }
 };
 
-/// @brief test class for Kea configuration backend
+/// @brief test class for Kea configuration backend.
 ///
 /// This class is used for testing Kea configuration backend.
 /// It is very simple and currently focuses on reading
@@ -201,6 +201,7 @@ public:
 
     ~JSONFileBackendTest() {
         LeaseMgrFactory::destroy();
+        isc::log::setDefaultLoggingOutput();
         static_cast<void>(remove(TEST_FILE));
         static_cast<void>(remove(TEST_INCLUDE));
     };
@@ -229,7 +230,7 @@ public:
     /// stops the IO service and causes the function to return.
     void runTimersWithTimeout(const IOServicePtr& io_service, const long timeout_ms,
                               std::function<bool()> cond = std::function<bool()>()) {
-        IntervalTimer timer(*io_service);
+        IntervalTimer timer(io_service);
         std::atomic<bool> stopped(false);
         timer.setup([&io_service, &stopped]() {
             stopped = true;
@@ -239,9 +240,10 @@ public:
         // Run as long as the timeout hasn't occurred and the interrupting
         // condition is not specified or not met.
         while (!stopped && (!cond || !cond())) {
-            io_service->run_one();
+            io_service->runOne();
         }
-        io_service->get_io_service().reset();
+        io_service->stop();
+        io_service->restart();
     }
 
     /// @brief This test verifies that the timer used to fetch the configuration
@@ -299,7 +301,6 @@ public:
         EXPECT_EQ(0, cb_control->getDatabaseCurrentConfigFetchCalls());
         EXPECT_EQ(1, cb_control->getDatabaseStagingConfigFetchCalls());
 
-
         if (call_command) {
             // The case where there is no backend is tested in the
             // controlled server tests so we have only to verify
@@ -310,9 +311,8 @@ public:
             EXPECT_EQ(cb_control->getDatabaseCurrentConfigFetchCalls(), 0);
             EXPECT_EQ(cb_control->getDatabaseStagingConfigFetchCalls(), 1);
 
-            ConstElementPtr result =
-                ControlledDhcpv4Srv::processCommand("config-backend-pull",
-                                                    ConstElementPtr());
+            ConstElementPtr list_cmds = createCommand("config-backend-pull");
+            ConstElementPtr result = CommandMgr::instance().processCommand(list_cmds);
             EXPECT_EQ(cb_control->getDatabaseTotalConfigFetchCalls(), 2);
             std::string expected;
 
@@ -1078,7 +1078,6 @@ testBackendReconfiguration(const std::string& backend_first,
               LeaseMgrFactory::instance().getType());
 }
 
-
 // This test verifies that backend specification can be added on
 // server reconfiguration.
 TEST_F(JSONFileBackendMySQLTest, reconfigureBackendUndefinedToMySQL) {
