@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -14,6 +14,7 @@
 #include <exceptions/exceptions.h>
 #include <dhcp/hwaddr.h>
 #include <dhcpsrv/lease.h>
+#include <dhcpsrv/network_state.h>
 #include <boost/pointer_cast.hpp>
 #include <gtest/gtest.h>
 #include <vector>
@@ -150,24 +151,32 @@ testCommandBasics(const ConstElementPtr& command,
 // This test verifies that the dhcp-disable command is correct.
 TEST(CommandCreatorTest, createDHCPDisable4) {
     // Create command with max-period value set to 20.
-    ConstElementPtr command = CommandCreator::createDHCPDisable(20, HAServerType::DHCPv4);
+    ConstElementPtr command = CommandCreator::createDHCPDisable(NetworkState::HA_REMOTE_COMMAND+1, 20,
+                                                                HAServerType::DHCPv4);
     ConstElementPtr arguments;
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-disable", "dhcp4",
                                               arguments));
-    ASSERT_EQ(2, arguments->size());
+    ASSERT_EQ(3, arguments->size());
     ConstElementPtr max_period = arguments->get("max-period");
     ASSERT_TRUE(max_period);
     ASSERT_EQ(Element::integer, max_period->getType());
     EXPECT_EQ(20, max_period->intValue());
+    ConstElementPtr origin_id = arguments->get("origin-id");
+    ASSERT_TRUE(origin_id);
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+1, origin_id->intValue());
     ConstElementPtr origin = arguments->get("origin");
     ASSERT_TRUE(origin);
     ASSERT_EQ("ha-partner", origin->stringValue());
 
     // Repeat the test but this time the max-period is not specified.
-    command = CommandCreator::createDHCPDisable(0, HAServerType::DHCPv4);
+    command = CommandCreator::createDHCPDisable(NetworkState::HA_REMOTE_COMMAND+1, 0,
+                                                HAServerType::DHCPv4);
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-disable", "dhcp4",
                                               arguments));
-    ASSERT_EQ(1, arguments->size());
+    ASSERT_EQ(2, arguments->size());
+    origin_id = arguments->get("origin-id");
+    ASSERT_TRUE(origin_id);
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+1, origin_id->intValue());
     origin = arguments->get("origin");
     ASSERT_TRUE(origin);
     ASSERT_EQ("ha-partner", origin->stringValue());
@@ -176,10 +185,14 @@ TEST(CommandCreatorTest, createDHCPDisable4) {
 // This test verifies that the dhcp-enable command is correct.
 TEST(CommandCreatorTest, createDHCPEnable4) {
     ConstElementPtr arguments;
-    ConstElementPtr command = CommandCreator::createDHCPEnable(HAServerType::DHCPv4);
+    ConstElementPtr command = CommandCreator::createDHCPEnable(NetworkState::HA_REMOTE_COMMAND+1,
+                                                               HAServerType::DHCPv4);
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-enable", "dhcp4",
                                               arguments));
-    ASSERT_EQ(1, arguments->size());
+    ASSERT_EQ(2, arguments->size());
+    ConstElementPtr origin_id = arguments->get("origin-id");
+    ASSERT_TRUE(origin_id);
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+1, origin_id->intValue());
     ConstElementPtr origin = arguments->get("origin");
     ASSERT_TRUE(origin);
     ASSERT_EQ("ha-partner", origin->stringValue());
@@ -187,14 +200,24 @@ TEST(CommandCreatorTest, createDHCPEnable4) {
 
 // This test verifies that the ha-reset command sent to DHCPv4 server is correct.
 TEST(CommandCreatorTest, createHAReset4) {
-    ConstElementPtr command = CommandCreator::createHAReset(HAServerType::DHCPv4);
-    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-reset", "dhcp4"));
+    ConstElementPtr command = CommandCreator::createHAReset("server1", HAServerType::DHCPv4);
+    ConstElementPtr arguments;
+    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-reset", "dhcp4", arguments));
+    auto server_name = arguments->get("server-name");
+    ASSERT_TRUE(server_name);
+    ASSERT_EQ(Element::string, server_name->getType());
+    EXPECT_EQ("server1", server_name->stringValue());
 }
 
 // This test verifies that the ha-heartbeat command is correct.
 TEST(CommandCreatorTest, createHeartbeat4) {
-    ConstElementPtr command = CommandCreator::createHeartbeat(HAServerType::DHCPv4);
-    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-heartbeat", "dhcp4"));
+    ConstElementPtr command = CommandCreator::createHeartbeat("server1", HAServerType::DHCPv4);
+    ConstElementPtr arguments;
+    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-heartbeat", "dhcp4", arguments));
+    auto server_name = arguments->get("server-name");
+    ASSERT_TRUE(server_name);
+    ASSERT_EQ(Element::string, server_name->getType());
+    EXPECT_EQ("server1", server_name->stringValue());
 }
 
 // This test verifies that the command generated for the lease update
@@ -283,24 +306,31 @@ TEST(CommandCreatorTest, createLease4GetPageZeroLimit) {
 // correct.
 TEST(CommandCreatorTest, createDHCPDisable6) {
     // Create command with max-period value set to 20.
-    ConstElementPtr command = CommandCreator::createDHCPDisable(20, HAServerType::DHCPv6);
+    ConstElementPtr command = CommandCreator::createDHCPDisable(NetworkState::HA_REMOTE_COMMAND+2, 20,
+                                                                HAServerType::DHCPv6);
     ConstElementPtr arguments;
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-disable", "dhcp6",
                                               arguments));
-    ASSERT_EQ(2, arguments->size());
+    ASSERT_EQ(3, arguments->size());
     ConstElementPtr max_period = arguments->get("max-period");
     ASSERT_TRUE(max_period);
     ASSERT_EQ(Element::integer, max_period->getType());
     EXPECT_EQ(20, max_period->intValue());
+    ConstElementPtr origin_id = arguments->get("origin-id");
+    ASSERT_TRUE(origin_id);
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+2, origin_id->intValue());
     ConstElementPtr origin = arguments->get("origin");
     ASSERT_TRUE(origin);
     ASSERT_EQ("ha-partner", origin->stringValue());
 
     // Repeat the test but this time the max-period is not specified.
-    command = CommandCreator::createDHCPDisable(0, HAServerType::DHCPv6);
+    command = CommandCreator::createDHCPDisable(NetworkState::HA_REMOTE_COMMAND+2, 0, HAServerType::DHCPv6);
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-disable", "dhcp6",
                                               arguments));
-    ASSERT_EQ(1, arguments->size());
+    ASSERT_EQ(2, arguments->size());
+    origin_id = arguments->get("origin-id");
+    ASSERT_TRUE(origin_id);
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+2, origin_id->intValue());
     origin = arguments->get("origin");
     ASSERT_TRUE(origin);
     ASSERT_EQ("ha-partner", origin->stringValue());
@@ -310,10 +340,13 @@ TEST(CommandCreatorTest, createDHCPDisable6) {
 // correct.
 TEST(CommandCreatorTest, createDHCPEnable6) {
     ConstElementPtr arguments;
-    ConstElementPtr command = CommandCreator::createDHCPEnable(HAServerType::DHCPv6);
+    ConstElementPtr command = CommandCreator::createDHCPEnable(NetworkState::HA_REMOTE_COMMAND+2, HAServerType::DHCPv6);
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-enable", "dhcp6",
                                               arguments));
-    ASSERT_EQ(1, arguments->size());
+    ASSERT_EQ(2, arguments->size());
+    ConstElementPtr origin_id = arguments->get("origin-id");
+    ASSERT_TRUE(origin_id);
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+2, origin_id->intValue());
     ConstElementPtr origin = arguments->get("origin");
     ASSERT_TRUE(origin);
     ASSERT_EQ("ha-partner", origin->stringValue());
@@ -321,8 +354,13 @@ TEST(CommandCreatorTest, createDHCPEnable6) {
 
 // This test verifies that the ha-reset command sent to DHCPv6 server is correct.
 TEST(CommandCreatorTest, createHAReset6) {
-    ConstElementPtr command = CommandCreator::createHAReset(HAServerType::DHCPv6);
-    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-reset", "dhcp6"));
+    ConstElementPtr arguments;
+    ConstElementPtr command = CommandCreator::createHAReset("server1", HAServerType::DHCPv6);
+    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-reset", "dhcp6", arguments));
+    auto server_name = arguments->get("server-name");
+    ASSERT_TRUE(server_name);
+    ASSERT_EQ(Element::string, server_name->getType());
+    EXPECT_EQ("server1", server_name->stringValue());
 }
 
 // This test verifies that the command generated for the lease update
@@ -487,7 +525,7 @@ TEST(CommandCreatorTest, createLease6GetPageZeroLimit) {
 // This test verifies that the ha-maintenance-notify command is correct
 // while being sent to the DHCPv4 server.
 TEST(CommandCreatorTest, createMaintenanceNotify4) {
-    ConstElementPtr command = CommandCreator::createMaintenanceNotify(true, HAServerType::DHCPv4);
+    ConstElementPtr command = CommandCreator::createMaintenanceNotify("server1", true, HAServerType::DHCPv4);
     ConstElementPtr arguments;
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-maintenance-notify", "dhcp4",
                                               arguments));
@@ -501,7 +539,7 @@ TEST(CommandCreatorTest, createMaintenanceNotify4) {
 // This test verifies that the ha-maintenance-notify command is correct
 // while being sent to the DHCPv6 server.
 TEST(CommandCreatorTest, createMaintenanceNotify6) {
-    ConstElementPtr command = CommandCreator::createMaintenanceNotify(false, HAServerType::DHCPv6);
+    ConstElementPtr command = CommandCreator::createMaintenanceNotify("server1", false, HAServerType::DHCPv6);
     ConstElementPtr arguments;
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-maintenance-notify", "dhcp6",
                                               arguments));
@@ -515,16 +553,41 @@ TEST(CommandCreatorTest, createMaintenanceNotify6) {
 // This test verifies that the ha-sync-complete-notify command sent to a
 // DHCPv4 server is correct.
 TEST(CommandCreatorTest, createSyncCompleteNotify4) {
-    ConstElementPtr command = CommandCreator::createSyncCompleteNotify(HAServerType::DHCPv4);
-    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-sync-complete-notify", "dhcp4"));
+    ConstElementPtr command = CommandCreator::createSyncCompleteNotify(1, "server1", HAServerType::DHCPv4);
+    ConstElementPtr arguments;
+    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-sync-complete-notify", "dhcp4", arguments));
+    auto server_name = arguments->get("server-name");
+    ASSERT_TRUE(server_name);
+    ASSERT_EQ(Element::string, server_name->getType());
+    EXPECT_EQ("server1", server_name->stringValue());
+    auto origin_id = arguments->get("origin-id");
+    ASSERT_TRUE(origin_id);
+    EXPECT_EQ(Element::integer, origin_id->getType());
+    EXPECT_EQ(1, origin_id->intValue());
+    auto origin = arguments->get("origin");
+    ASSERT_TRUE(origin);
+    EXPECT_EQ(Element::integer, origin->getType());
+    EXPECT_EQ(1, origin->intValue());
 }
 
 // This test verifies that the ha-sync-complete-notify command sent to a
-// DHCPv4 server is correct.
+// DHCPv6 server is correct.
 TEST(CommandCreatorTest, createSyncCompleteNotify6) {
-    ConstElementPtr command = CommandCreator::createSyncCompleteNotify(HAServerType::DHCPv6);
+    ConstElementPtr command = CommandCreator::createSyncCompleteNotify(1, "server1", HAServerType::DHCPv6);
     ConstElementPtr arguments;
-    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-sync-complete-notify", "dhcp6"));
+    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-sync-complete-notify", "dhcp6", arguments));
+    auto server_name = arguments->get("server-name");
+    ASSERT_TRUE(server_name);
+    ASSERT_EQ(Element::string, server_name->getType());
+    EXPECT_EQ("server1", server_name->stringValue());
+    auto origin_id = arguments->get("origin-id");
+    ASSERT_TRUE(origin_id);
+    EXPECT_EQ(Element::integer, origin_id->getType());
+    EXPECT_EQ(1, origin_id->intValue());
+    auto origin = arguments->get("origin");
+    ASSERT_TRUE(origin);
+    EXPECT_EQ(Element::integer, origin->getType());
+    EXPECT_EQ(1, origin->intValue());
 }
 
 }
