@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2022 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -81,6 +81,7 @@ namespace {
     "  x.formatted_value," \
     "  x.space," \
     "  x.persistent," \
+    "  x.cancelled," \
     "  x.dhcp4_subnet_id," \
     "  x.scope_id," \
     "  x.user_context," \
@@ -93,6 +94,7 @@ namespace {
     "  o.formatted_value," \
     "  o.space," \
     "  o.persistent," \
+    "  o.cancelled," \
     "  o.dhcp4_subnet_id," \
     "  o.scope_id," \
     "  o.user_context," \
@@ -118,6 +120,8 @@ namespace {
     "  s.reservations_out_of_pool," \
     "  s.cache_threshold," \
     "  s.cache_max_age," \
+    "  s.offer_lifetime, " \
+    "  s.allocator, " \
     "  srv.tag " \
     "FROM dhcp4_subnet AS s " \
     server_join \
@@ -187,6 +191,7 @@ namespace {
     "  x.formatted_value," \
     "  x.space," \
     "  x.persistent," \
+    "  x.cancelled," \
     "  x.dhcp6_subnet_id," \
     "  x.scope_id," \
     "  x.user_context," \
@@ -200,6 +205,7 @@ namespace {
     "  y.formatted_value," \
     "  y.space," \
     "  y.persistent," \
+    "  y.cancelled," \
     "  y.dhcp6_subnet_id," \
     "  y.scope_id," \
     "  y.user_context," \
@@ -213,6 +219,7 @@ namespace {
     "  o.formatted_value," \
     "  o.space," \
     "  o.persistent," \
+    "  o.cancelled," \
     "  o.dhcp6_subnet_id," \
     "  o.scope_id," \
     "  o.user_context," \
@@ -246,6 +253,8 @@ namespace {
     "  s.reservations_out_of_pool," \
     "  s.cache_threshold," \
     "  s.cache_max_age," \
+    "  s.allocator," \
+    "  s.pd_allocator," \
     "  srv.tag " \
     "FROM dhcp6_subnet AS s " \
     server_join \
@@ -299,6 +308,7 @@ namespace {
       "  x.formatted_value," \
       "  x.space," \
       "  x.persistent," \
+      "  x.cancelled," \
       "  x.dhcp4_subnet_id," \
       "  x.scope_id," \
       "  x.user_context," \
@@ -339,6 +349,7 @@ namespace {
     "  x.formatted_value," \
     "  x.space," \
     "  x.persistent," \
+    "  x.cancelled," \
     "  x.dhcp6_subnet_id," \
     "  x.scope_id," \
     "  x.user_context," \
@@ -383,6 +394,7 @@ namespace {
     "  x.formatted_value," \
     "  x.space," \
     "  x.persistent," \
+    "  x.cancelled," \
     "  x.dhcp6_subnet_id," \
     "  x.scope_id," \
     "  x.user_context," \
@@ -429,6 +441,7 @@ namespace {
     "  o.formatted_value," \
     "  o.space," \
     "  o.persistent," \
+    "  o.cancelled," \
     "  o.dhcp4_subnet_id," \
     "  o.scope_id," \
     "  o.user_context," \
@@ -454,6 +467,8 @@ namespace {
     "  n.reservations_out_of_pool," \
     "  n.cache_threshold," \
     "  n.cache_max_age," \
+    "  n.offer_lifetime, " \
+    "  n.allocator, " \
     "  s.tag " \
     "FROM dhcp4_shared_network AS n " \
     server_join \
@@ -509,6 +524,7 @@ namespace {
     "  o.formatted_value," \
     "  o.space," \
     "  o.persistent," \
+    "  o.cancelled," \
     "  o.dhcp6_subnet_id," \
     "  o.scope_id," \
     "  o.user_context," \
@@ -534,6 +550,8 @@ namespace {
     "  n.reservations_out_of_pool," \
     "  n.cache_threshold," \
     "  n.cache_max_age," \
+    "  n.allocator," \
+    "  n.pd_allocator," \
     "  s.tag " \
     "FROM dhcp6_shared_network AS n " \
     server_join \
@@ -598,6 +616,7 @@ namespace {
     "  o.formatted_value," \
     "  o.space," \
     "  o.persistent," \
+    "  o.cancelled," \
     "  o." #table_prefix "_subnet_id," \
     "  o.scope_id," \
     "  o.user_context," \
@@ -676,6 +695,7 @@ namespace {
     "  o.depend_on_known_indirectly, " \
     "  c.modification_ts," \
     "  c.user_context," \
+    "  c.offer_lifetime," \
     "  d.id," \
     "  d.code," \
     "  d.name," \
@@ -692,6 +712,7 @@ namespace {
     "  x.formatted_value," \
     "  x.space," \
     "  x.persistent," \
+    "  x.cancelled," \
     "  x.dhcp4_subnet_id," \
     "  x.scope_id," \
     "  x.user_context," \
@@ -755,6 +776,7 @@ namespace {
     "  x.formatted_value," \
     "  x.space," \
     "  x.persistent," \
+    "  x.cancelled," \
     "  x.dhcp6_subnet_id," \
     "  x.scope_id," \
     "  x.user_context," \
@@ -909,6 +931,7 @@ namespace {
     "  formatted_value," \
     "  space," \
     "  persistent," \
+    "  cancelled," \
     "  dhcp_client_class," \
     " " #table_prefix "_subnet_id," \
     "  scope_id," \
@@ -917,7 +940,7 @@ namespace {
     "  pool_id," \
     "  modification_ts" \
     pd_pool_id \
-    ") VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?" last ")"
+    ") VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?" last ")"
 
 #define MYSQL_INSERT_OPTION4() \
     MYSQL_INSERT_OPTION_COMMON(dhcp4, "", "")
@@ -1014,7 +1037,7 @@ namespace {
     "  d.encapsulate = ?," \
     "  d.record_types = ?," \
     "  d.user_context = ? " \
-    "WHERE d.class_id = (SELECT id FROM dhcp4_client_class WHERE name = ?) " \
+    "WHERE d.class_id = (SELECT id FROM " #table_prefix "_client_class WHERE name = ?) " \
     "  AND s.tag = ? AND d.code = ? AND d.space = ?"
 #endif
 
@@ -1028,6 +1051,7 @@ namespace {
     "  o.formatted_value = ?," \
     "  o.space = ?," \
     "  o.persistent = ?," \
+    "  o.cancelled = ?," \
     "  o.dhcp_client_class = ?," \
     "  o." #table_prefix "_subnet_id = ?," \
     "  o.scope_id = ?," \
@@ -1076,7 +1100,8 @@ namespace {
     "  depend_on_known_directly = ?," \
     follow_class_name_set \
     "  modification_ts = ?, " \
-    "  user_context = ? " \
+    "  user_context = ?," \
+    "  offer_lifetime = ? "\
     "WHERE name = ?"
 #endif
 
