@@ -1,4 +1,4 @@
-// Copyright (C) 2020-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2020-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -27,7 +27,7 @@ public:
     ///
     /// @param io_service the process IO service.
     /// @param handler the signal handler.
-    IOSignalSetImpl(IOServicePtr io_service, IOSignalHandler handler);
+    IOSignalSetImpl(const IOServicePtr& io_service, IOSignalHandler handler);
 
     /// @brief Destructor.
     ~IOSignalSetImpl();
@@ -65,10 +65,10 @@ private:
     void callback(const boost::system::error_code& ec, int signum);
 };
 
-IOSignalSetImpl::IOSignalSetImpl(IOServicePtr io_service,
+IOSignalSetImpl::IOSignalSetImpl(const IOServicePtr& io_service,
                                  IOSignalHandler handler)
     : io_service_(io_service),
-      signal_set_(io_service_->get_io_service()),
+      signal_set_(io_service_->getInternalIOService()),
       handler_(handler) {
 }
 
@@ -122,7 +122,7 @@ IOSignalSetImpl::remove(int signum) {
     }
 }
 
-IOSignalSet::IOSignalSet(IOServicePtr io_service, IOSignalHandler handler) :
+IOSignalSet::IOSignalSet(const IOServicePtr& io_service, IOSignalHandler handler) :
     impl_(new IOSignalSetImpl(io_service, handler)) {
     // It can throw but the error is fatal...
     impl_->install();
