@@ -1,10 +1,10 @@
-// Copyright (C) 2011-2016 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-/// \brief Test of TCPSocket
+/// @brief Test of TCPSocket
 ///
 /// Tests the functionality of a TCPSocket by working through an open-send-
 /// receive-close sequence and checking that the asynchronous notifications
@@ -16,34 +16,35 @@
 #include <asiolink/tcp_endpoint.h>
 #include <asiolink/tcp_socket.h>
 #include <util/buffer.h>
-#include <util/io_utilities.h>
+#include <util/io.h>
 
-#include <boost/bind.hpp>
 #include <boost/shared_ptr.hpp>
 #include <gtest/gtest.h>
 
-#include <string>
+#include <algorithm>
 #include <arpa/inet.h>
+#include <cstddef>
+#include <cstdlib>
+#include <errno.h>
 #include <netinet/in.h>
 #include <sys/types.h>
 #include <sys/socket.h>
-#include <algorithm>
-#include <cstdlib>
-#include <cstddef>
+#include <string>
 #include <vector>
 
+using namespace isc::asiolink;
+using namespace isc::util;
+
+using namespace std;
 using namespace boost::asio;
 using namespace boost::asio::ip;
-using namespace isc::util;
-using namespace isc::asiolink;
-using namespace std;
 
 namespace {
 
 const char SERVER_ADDRESS[] = "127.0.0.1";
 const unsigned short SERVER_PORT = 5303;
 
-// TODO: Shouldn't we send something that is real message?
+/// @todo Shouldn't we send something that is real message?
 const char OUTBOUND_DATA[] = "Data sent from client to server";
 const char INBOUND_DATA[] = "Returned data from server to client";
 }
@@ -53,7 +54,7 @@ const char INBOUND_DATA[] = "Returned data from server to client";
 /// The arguments to the completion callback are stored for later retrieval.
 class TCPCallback {
 public:
-    /// \brief Operations the server is doing
+    /// @brief Operations the server is doing
     enum Operation {
         ACCEPT = 0,     ///< accept() was issued
         OPEN = 1,       /// Client connected to server
@@ -62,7 +63,7 @@ public:
         NONE = 4        ///< "Not set" state
     };
 
-    /// \brief Minimim size of buffers
+    /// @brief Minimum size of buffers
     enum {
         MIN_SIZE = (64 * 1024 + 2)          ///< 64kB + two bytes for a count
     };
@@ -84,7 +85,7 @@ public:
         std::vector<uint8_t>       data_;          ///< Receive buffer
     };
 
-    /// \brief Constructor
+    /// @brief Constructor
     ///
     /// Constructs the object.  It also creates the data member pointed to by
     /// a shared pointer.  When used as a callback object, this is copied as it
@@ -95,25 +96,25 @@ public:
     /// shared pointer is copied, which leaves both objects pointing to the same
     /// data.
     ///
-    /// \param which Which of the two callback objects this is
+    /// @param which Which of the two callback objects this is
     TCPCallback(std::string which) : ptr_(new PrivateData())
     {
         ptr_->name_ = which;
     }
 
-    /// \brief Destructor
+    /// @brief Destructor
     ///
     /// No code needed, destroying the shared pointer destroys the private data.
     virtual ~TCPCallback()
     {}
 
-    /// \brief Client Callback Function
+    /// @brief Client Callback Function
     ///
     /// Called when an asynchronous operation is completed by the client, this
     /// stores the origin of the operation in the client_called_ data member.
     ///
-    /// \param ec I/O completion error code passed to callback function.
-    /// \param length Number of bytes transferred
+    /// @param ec I/O completion error code passed to callback function.
+    /// @param length Number of bytes transferred
     void operator()(boost::system::error_code ec = boost::system::error_code(),
                             size_t length = 0)
     {
@@ -122,54 +123,54 @@ public:
         ptr_->length_ = length;
     }
 
-    /// \brief Get I/O completion error code
+    /// @brief Get I/O completion error code
     int getCode() {
         return (ptr_->error_code_.value());
     }
 
-    /// \brief Set I/O completion code
+    /// @brief Set I/O completion code
     ///
-    /// \param code New value of completion code
+    /// @param code New value of completion code
     void setCode(int code) {
         ptr_->error_code_ = boost::system::error_code(code, boost::system::error_code().category());
     }
 
-    /// \brief Get number of bytes transferred in I/O
+    /// @brief Get number of bytes transferred in I/O
     size_t& length() {
         return (ptr_->length_);
     }
 
-    /// \brief Get cumulative number of bytes transferred in I/O
+    /// @brief Get cumulative number of bytes transferred in I/O
     size_t& cumulative() {
         return (ptr_->cumulative_);
     }
 
-    /// \brief Get expected amount of data
+    /// @brief Get expected amount of data
     size_t& expected() {
         return (ptr_->expected_);
     }
 
-    /// \brief Get offset intodData
+    /// @brief Get offset into data
     size_t& offset() {
         return (ptr_->offset_);
     }
 
-    /// \brief Get data member
+    /// @brief Get data member
     uint8_t* data() {
         return (&ptr_->data_[0]);
     }
 
-    /// \brief Get flag to say what was queued
+    /// @brief Get flag to say what was queued
     Operation& queued() {
         return (ptr_->queued_);
     }
 
-    /// \brief Get flag to say when callback was called
+    /// @brief Get flag to say when callback was called
     Operation& called() {
         return (ptr_->called_);
     }
 
-    /// \brief Return instance of callback name
+    /// @brief Return instance of callback name
     std::string& name() {
         return (ptr_->name_);
     }
@@ -190,8 +191,8 @@ private:
 // from the remote end is equal to the value in the count field plus two bytes
 // for the count field itself.
 //
-// \param socket Socket on which the server is reading data
-// \param server_cb Structure in which server data is held.
+// @param socket Socket on which the server is reading data
+// @param server_cb Structure in which server data is held.
 void
 serverRead(tcp::socket& socket, TCPCallback& server_cb) {
 
@@ -234,7 +235,7 @@ serverRead(tcp::socket& socket, TCPCallback& server_cb) {
 TEST(TCPSocket, processReceivedData) {
     const uint16_t PACKET_SIZE = 16382;     // Amount of "real" data in the buffer
 
-    IOService               service;        // Used to instantiate socket
+    IOServicePtr            service(new IOService());  // Used to instantiate socket
     TCPSocket<TCPCallback>  test(service);  // Socket under test
     uint8_t                 inbuff[PACKET_SIZE + 2];   // Buffer to check
     OutputBufferPtr         outbuff(new OutputBuffer(16));
@@ -283,7 +284,7 @@ TEST(TCPSocket, processReceivedData) {
     EXPECT_EQ(PACKET_SIZE, expected);
     EXPECT_EQ(2, outbuff->getLength());
 
-    const uint8_t* dataptr = static_cast<const uint8_t*>(outbuff->getData());
+    const uint8_t* dataptr = outbuff->getData();
     EXPECT_TRUE(equal(inbuff + 2, inbuff + cumulative, dataptr));
 
     // And add the remaining data.  Remember that "inbuff" is "PACKET_SIZE + 2"
@@ -296,11 +297,11 @@ TEST(TCPSocket, processReceivedData) {
     EXPECT_EQ(0, offset);
     EXPECT_EQ(PACKET_SIZE, expected);
     EXPECT_EQ(PACKET_SIZE, outbuff->getLength());
-    dataptr = static_cast<const uint8_t*>(outbuff->getData());
+    dataptr = outbuff->getData();
     EXPECT_TRUE(equal(inbuff + 2, inbuff + cumulative, dataptr));
 }
 
-// TODO: Need to add a test to check the cancel() method
+/// @todo Need to add a test to check the cancel() method
 
 // Tests the operation of a TCPSocket by opening it, sending an asynchronous
 // message to a server, receiving an asynchronous message from the server and
@@ -308,10 +309,10 @@ TEST(TCPSocket, processReceivedData) {
 TEST(TCPSocket, sequenceTest) {
 
     // Common objects.
-    IOService   service;                    // Service object for async control
+    IOServicePtr service(new IOService());  // Service object for async control
 
     // The client - the TCPSocket being tested
-    TCPSocket<TCPCallback>  client(service);// Socket under test
+    TCPSocket<TCPCallback> client(service); // Socket under test
     TCPCallback client_cb("Client");        // Async I/O callback function
     TCPEndpoint client_remote_endpoint;     // Where client receives message from
     OutputBufferPtr client_buffer(new OutputBuffer(128));
@@ -324,7 +325,7 @@ TEST(TCPSocket, sequenceTest) {
     TCPEndpoint server_endpoint(server_address, SERVER_PORT);
                                             // Endpoint describing server
     TCPEndpoint server_remote_endpoint;     // Address where server received message from
-    tcp::socket server_socket(service.get_io_service());
+    tcp::socket server_socket(service->getInternalIOService());
                                             // Socket used for server
 
     // Step 1.  Create the connection between the client and the server.  Set
@@ -335,8 +336,8 @@ TEST(TCPSocket, sequenceTest) {
     server_cb.queued() = TCPCallback::ACCEPT;
     server_cb.called() = TCPCallback::NONE;
     server_cb.setCode(42);  // Some error
-    tcp::acceptor acceptor(service.get_io_service(),
-                            tcp::endpoint(tcp::v4(), SERVER_PORT));
+    tcp::acceptor acceptor(service->getInternalIOService(),
+                           tcp::endpoint(tcp::v4(), SERVER_PORT));
     acceptor.set_option(tcp::acceptor::reuse_address(true));
     acceptor.async_accept(server_socket, server_cb);
 
@@ -348,14 +349,22 @@ TEST(TCPSocket, sequenceTest) {
     client.open(&server_endpoint, client_cb);
 
     // Run the open and the accept callback and check that they ran.
-    service.run_one();
-    service.run_one();
+    service->runOne();
+    service->runOne();
 
     EXPECT_EQ(TCPCallback::ACCEPT, server_cb.called());
     EXPECT_EQ(0, server_cb.getCode());
 
     EXPECT_EQ(TCPCallback::OPEN, client_cb.called());
-    EXPECT_EQ(0, client_cb.getCode());
+
+    // On some operating system the async_connect may return EINPROGRESS.
+    // This doesn't necessarily indicate an error. In most cases trying
+    // to asynchronously write and read from the socket would work just
+    // fine.
+    if ((client_cb.getCode()) != 0 && (client_cb.getCode() != EINPROGRESS)) {
+        ADD_FAILURE() << "expected error code of 0 or " << EINPROGRESS
+            << " as a result of async_connect, got " << client_cb.getCode();
+    }
 
     // Step 2.  Get the client to write to the server asynchronously.  The
     // server will loop reading the data synchronously.
@@ -369,7 +378,7 @@ TEST(TCPSocket, sequenceTest) {
 
     // Wait for the client callback to complete. (Must do this first on
     // Solaris: if we do the synchronous read first, the test hangs.)
-    service.run_one();
+    service->runOne();
 
     // Synchronously read the data from the server.;
     serverRead(server_socket, server_cb);
@@ -418,7 +427,7 @@ TEST(TCPSocket, sequenceTest) {
     // Run the callbacks. Several options are possible depending on how ASIO
     // is implemented and whether the message gets fragmented:
     //
-    // 1) The send handler may complete immediately, regardess of whether the
+    // 1) The send handler may complete immediately, regardless of whether the
     // data has been read by the client.  (This is the most likely.)
     // 2) The send handler may only run after all the data has been read by
     // the client. (This could happen if the client's TCP buffers were too
@@ -434,7 +443,7 @@ TEST(TCPSocket, sequenceTest) {
     bool server_complete = false;
     bool client_complete = false;
     while (!server_complete || !client_complete) {
-        service.run_one();
+        service->runOne();
 
         // Has the server run?
         if (!server_complete) {
@@ -497,7 +506,7 @@ TEST(TCPSocket, sequenceTest) {
     EXPECT_EQ(sizeof(INBOUND_DATA) + 2, server_cb.length());
 
     // ... and that what was sent is what was received.
-    const uint8_t* received = static_cast<const uint8_t*>(client_buffer->getData());
+    const uint8_t* received = client_buffer->getData();
     EXPECT_TRUE(equal(INBOUND_DATA, (INBOUND_DATA + (sizeof(INBOUND_DATA) - 1)),
                       received));
 
