@@ -1,4 +1,4 @@
-// Copyright (C) 2017-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2017-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -6,13 +6,14 @@
 
 #include <config.h>
 
+#include <asiolink/io_service_mgr.h>
 #include <d2srv/d2_config.h>
 #include <d2srv/d2_simple_parser.h>
 #include <cc/data.h>
 #include <hooks/hooks_manager.h>
 #include <hooks/hooks_parser.h>
-#include <boost/foreach.hpp>
 
+using namespace isc::asiolink;
 using namespace isc::data;
 using namespace isc::d2;
 using namespace isc;
@@ -185,7 +186,7 @@ D2SimpleParser::setManagerDefaults(ElementPtr global,
         // manager is disabled.
         if (mgr->find("ddns-domains")) {
             ConstElementPtr domains = mgr->get("ddns-domains");
-            BOOST_FOREACH(ElementPtr domain, domains->listValue()) {
+            for (auto const& domain : domains->listValue()) {
                 // Set the domain's defaults.  We can't use setListDefaults()
                 // as this does not handle sub-lists or maps, like server list.
                 cnt += setDdnsDomainDefaults(domain, DDNS_DOMAIN_DEFAULTS);
@@ -237,16 +238,7 @@ void D2SimpleParser::parse(const D2CfgContextPtr& ctx,
     dhcp_ddns::NameChangeFormat ncr_format = dhcp_ddns::FMT_JSON;
 
     ip_address = SimpleParser::getAddress(config, "ip-address");
-
-    if ((ip_address.toText() == "0.0.0.0") ||
-        (ip_address.toText() == "::")) {
-        isc_throw(D2CfgError, "IP address cannot be \""
-                  << ip_address << "\""
-                  << " (" << config->get("ip-address")->getPosition() << ")");
-    }
-
     port = SimpleParser::getUint32(config, "port");
-
     dns_server_timeout = SimpleParser::getUint32(config, "dns-server-timeout");
 
     ncr_protocol = getProtocol(config, "ncr-protocol");
@@ -302,6 +294,7 @@ void D2SimpleParser::parse(const D2CfgContextPtr& ctx,
         // change causes problems when trying to roll back.
         HooksManager::prepareUnloadLibraries();
         static_cast<void>(HooksManager::unloadLibraries());
+        IOServiceMgr::instance().clearIOServices();
         libraries.loadLibraries(false);
     }
 }
