@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2017 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -352,7 +352,7 @@ TEST_F(OptionDataTypesTest, writeBool) {
     ASSERT_EQ(2, buf.size());
     // Check that the first value has not changed.
     EXPECT_EQ(buf[0], 1);
-    // Check the the second value is correct.
+    // Check the second value is correct.
     EXPECT_EQ(buf[1], 0);
 }
 
@@ -750,6 +750,18 @@ TEST_F(OptionDataTypesTest, readPsid) {
 
     buf.clear();
 
+    // PSID length is 16 (bits)
+    writeInt<uint8_t>(16, buf);
+    // 0xF000 is represented as 1111000000000000b, which is equivalent
+    // of portset 0xF000.
+    writeInt<uint16_t>(0xF000, buf);
+
+    ASSERT_NO_THROW(psid = OptionDataTypeUtil::readPsid(buf));
+    EXPECT_EQ(16, psid.first.asUnsigned());
+    EXPECT_EQ(0xF000, psid.second.asUint16());
+
+    buf.clear();
+
     // PSID length is 0, in which case PSID should be ignored.
     writeInt<uint8_t>(0, buf);
     // Let's put some junk into the PSID field to make sure it will
@@ -778,11 +790,21 @@ TEST_F(OptionDataTypesTest, readPsid) {
 
     buf.clear();
 
-    // Buffer is truncated -  2 bytes instead of 3.
+    // Buffer is truncated - 2 bytes instead of 3.
     writeInt<uint8_t>(4, buf);
     writeInt<uint8_t>(0xF0, buf);
     EXPECT_THROW(static_cast<void>(OptionDataTypeUtil::readPsid(buf)),
                  BadDataTypeCast);
+
+    // Check for out of range values.
+    for (int i = 1; i < 16; ++i) {
+        buf.clear();
+        writeInt<uint8_t>(i, buf);
+        writeInt<uint16_t>(0xFFFF << (15 - i), buf);
+        EXPECT_THROW(static_cast<void>(OptionDataTypeUtil::readPsid(buf)),
+                     BadDataTypeCast);
+    }
+
 }
 
 // The purpose of this test is to verify that the PSID-len/PSID
@@ -837,16 +859,17 @@ TEST_F(OptionDataTypesTest, writePsid) {
     EXPECT_THROW(OptionDataTypeUtil::writePsid(PSIDLen(17), PSID(1), buf),
                  OutOfRange);
 
-    // PSID length is 1, which allows for coding up to two (2^1)
-    // port sets. These are namely port set 0 and port set 1. The
-    // value of 2 is out of that range.
-    EXPECT_THROW(OptionDataTypeUtil::writePsid(PSIDLen(1), PSID(2), buf),
-                 BadDataTypeCast);
+    // Check for out of range values.
+    for (int i = 1; i < 16; ++i) {
+        EXPECT_THROW(OptionDataTypeUtil::writePsid(PSIDLen(i), PSID(1 << i), buf),
+                     BadDataTypeCast);
+    }
 }
 
 // The purpose of this test is to verify that the string
 // can be read from a buffer correctly.
 TEST_F(OptionDataTypesTest, readString) {
+
     // Prepare a buffer with some string in it.
     std::vector<uint8_t> buf;
     writeString("hello world", buf);
@@ -858,6 +881,34 @@ TEST_F(OptionDataTypesTest, readString) {
     );
     // Check that it is valid.
     EXPECT_EQ("hello world", value);
+
+    // Only nulls should throw.
+    OptionBuffer buffer = { 0, 0 };
+    ASSERT_THROW(OptionDataTypeUtil::readString(buffer), isc::OutOfRange);
+
+    // One trailing null should trim off.
+    buffer = {'o', 'n', 'e', 0 };
+    ASSERT_NO_THROW(value = OptionDataTypeUtil::readString(buffer));
+    EXPECT_EQ(3, value.length());
+    EXPECT_EQ(value, std::string("one"));
+
+    // More than one trailing null should trim off.
+    buffer = { 't', 'h', 'r', 'e', 'e', 0, 0, 0 };
+    ASSERT_NO_THROW(value = OptionDataTypeUtil::readString(buffer));
+    EXPECT_EQ(5, value.length());
+    EXPECT_EQ(value, std::string("three"));
+
+    // Embedded null should be left in place.
+    buffer = { 'e', 'm', 0, 'b', 'e', 'd' };
+    ASSERT_NO_THROW(value = OptionDataTypeUtil::readString(buffer));
+    EXPECT_EQ(6, value.length());
+    EXPECT_EQ(value, (std::string{"em\0bed", 6}));
+
+    // Leading null should be left in place.
+    buffer = { 0, 'l', 'e', 'a', 'd', 'i', 'n', 'g' };
+    ASSERT_NO_THROW(value = OptionDataTypeUtil::readString(buffer));
+    EXPECT_EQ(8, value.length());
+    EXPECT_EQ(value, (std::string{"\0leading", 8}));
 }
 
 // The purpose of this test is to verify that a string can be
