@@ -1,4 +1,4 @@
-// Copyright (C) 2011-2016 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -10,10 +10,11 @@
 #include <dhcp/libdhcp++.h>
 #include <dhcp/option.h>
 #include <dhcp/option_int.h>
+#include <dhcp/option_space.h>
 #include <exceptions/exceptions.h>
 #include <util/buffer.h>
+#include <testutils/gtest_utils.h>
 
-#include <boost/bind.hpp>
 #include <boost/shared_ptr.hpp>
 #include <boost/scoped_ptr.hpp>
 #include <gtest/gtest.h>
@@ -69,13 +70,11 @@ TEST_F(OptionTest, v4_basic) {
     EXPECT_NO_THROW(opt.reset());
 
     // V4 options have type 0...255
-    EXPECT_THROW(opt.reset(new Option(Option::V4, 256)), BadValue);
+    EXPECT_THROW(opt.reset(new Option(Option::V4, 256)), OutOfRange);
 
-    // 0 is a special PAD option
-    EXPECT_THROW(opt.reset(new Option(Option::V4, 0)), BadValue);
-
-    // 255 is a special END option
-    EXPECT_THROW(opt.reset(new Option(Option::V4, 255)), BadValue);
+    // 0 / PAD and 255 / END are no longer forbidden
+    EXPECT_NO_THROW(opt.reset(new Option(Option::V4, 0)));
+    EXPECT_NO_THROW(opt.reset(new Option(Option::V4, 255)));
 }
 
 const uint8_t dummyPayload[] =
@@ -130,7 +129,7 @@ TEST_F(OptionTest, v4_data2) {
     data.push_back(67);
 
     // Data contains extra garbage at beginning and at the end. It should be
-    // ignored, as we pass interators to proper data. Only subset (limited by
+    // ignored, as we pass iterators to proper data. Only subset (limited by
     // iterators) of the vector should be used.
     // expData contains expected content (just valid data, without garbage).
     scoped_ptr<Option> opt;
@@ -209,8 +208,8 @@ TEST_F(OptionTest, v4_toHexString) {
     opt_too_long.addOption(sub1);
     opt_too_long.addOption(sub2);
 
-    // The toHexString() should throw exception.
-    EXPECT_THROW(opt_too_long.toHexString(), isc::OutOfRange);
+    // The toHexString() should not throw exception.
+    EXPECT_NO_THROW(opt_too_long.toHexString());
 }
 
 // Tests simple constructor
@@ -245,7 +244,7 @@ TEST_F(OptionTest, v6_data1) {
     opt->pack(outBuf_);
     EXPECT_EQ(11, outBuf_.getLength());
 
-    const uint8_t* out = static_cast<const uint8_t*>(outBuf_.getData());
+    const uint8_t* out = outBuf_.getData();
     EXPECT_EQ(out[0], 333 / 256); // Type
     EXPECT_EQ(out[1], 333 % 256);
 
@@ -281,7 +280,7 @@ TEST_F(OptionTest, v6_data2) {
 
     // Check if pack worked properly:
     // If option type is correct
-    const uint8_t* out = static_cast<const uint8_t*>(outBuf_.getData());
+    const uint8_t* out = outBuf_.getData();
 
     EXPECT_EQ(D6O_CLIENTID, out[0] * 256 + out[1]);
 
@@ -522,7 +521,7 @@ TEST_F(OptionTest, setData) {
     opt1->setData(buf_.begin(), buf_.end());
     opt1->pack(outBuf_);
     ASSERT_EQ(outBuf_.getLength() - opt1->getHeaderLen(), buf_.size());
-    const uint8_t* test_data = static_cast<const uint8_t*>(outBuf_.getData());
+    const uint8_t* test_data = outBuf_.getData();
     EXPECT_TRUE(0 == memcmp(&buf_[0], test_data + opt1->getHeaderLen(),
                             buf_.size()));
 
@@ -535,7 +534,7 @@ TEST_F(OptionTest, setData) {
     opt2->setData(buf_.begin(), buf_.end());
     opt2->pack(outBuf_);
     ASSERT_EQ(outBuf_.getLength() - opt1->getHeaderLen(), buf_.size());
-    test_data = static_cast<const uint8_t*>(outBuf_.getData());
+    test_data = outBuf_.getData();
     EXPECT_TRUE(0 == memcmp(&buf_[0], test_data + opt1->getHeaderLen(),
                             buf_.size()));
 }
@@ -593,15 +592,14 @@ TEST_F(OptionTest, setEncapsulatedSpace) {
     Option optv6(Option::V6, 258);
     EXPECT_TRUE(optv6.getEncapsulatedSpace().empty());
 
-    optv6.setEncapsulatedSpace("dhcp6");
-    EXPECT_EQ("dhcp6", optv6.getEncapsulatedSpace());
+    optv6.setEncapsulatedSpace(DHCP6_OPTION_SPACE);
+    EXPECT_EQ(DHCP6_OPTION_SPACE, optv6.getEncapsulatedSpace());
 
     Option optv4(Option::V4, 125);
     EXPECT_TRUE(optv4.getEncapsulatedSpace().empty());
 
-    optv4.setEncapsulatedSpace("dhcp4");
-    EXPECT_EQ("dhcp4", optv4.getEncapsulatedSpace());
-
+    optv4.setEncapsulatedSpace(DHCP4_OPTION_SPACE);
+    EXPECT_EQ(DHCP4_OPTION_SPACE, optv4.getEncapsulatedSpace());
 }
 
 // This test verifies that cloneInternal returns NULL pointer if
@@ -618,4 +616,36 @@ TEST_F(OptionTest, cloneInternal) {
     EXPECT_FALSE(clone);
 }
 
+// This test verifies that empty option factory function creates
+// a valid option instance.
+TEST_F(OptionTest, create) {
+    auto option = Option::create(Option::V4, 123);
+    ASSERT_TRUE(option);
+    EXPECT_EQ(Option::V4, option->getUniverse());
+    EXPECT_EQ(123, option->getType());
+}
+
+// This test verifies that option factory function creates a
+// valid option instance.
+TEST_F(OptionTest, createPayload) {
+    auto option = Option::create(Option::V4, 123, buf_);
+    ASSERT_TRUE(option);
+    EXPECT_EQ(Option::V4, option->getUniverse());
+    EXPECT_EQ(123, option->getType());
+    EXPECT_EQ(buf_, option->getData());
+}
+
+// Verify that options cannot be added to themselves as suboptions.
+TEST_F(OptionTest, optionsCannotContainThemselves) {
+    OptionBuffer buf1 {0xaa, 0xbb};
+    OptionBuffer buf2 {0xcc, 0xdd};
+    OptionPtr option = Option::create(Option::V4, 123, buf1);
+    OptionPtr option2 = Option::create(Option::V4, 124, buf2);
+    ASSERT_TRUE(option);
+    ASSERT_NO_THROW(option->addOption(option2));
+    EXPECT_THROW_MSG(option->addOption(option), InvalidOperation,
+        "option cannot be added to itself: type=123, len=006: aa:bb,\noptions:\n"
+        "  type=124, len=002: cc:dd");
+}
+
 }
