@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -73,12 +73,33 @@ public:
     /// @param rcvd_msg An instance of the message to be tested.
     void testRcvdMessage(const Pkt6Ptr& rcvd_msg) const;
 
+    /// @brief Checks that a received message has the appropriate events
+    /// in it's event stack.
+    ///
+    /// @param msg An instance of the message to be tested.
+    /// @param so_time_supported If true the event stack should have
+    /// a SOCKET_RECEIVED event followed by a BUFFER_READ event, if false
+    /// it should have only the latter.
+    void testReceivedPktEvents(const PktPtr& msg, bool so_time_supported) const;
+
+    /// @brief Checks the contents of a packet's event stack agains a list
+    /// of expected events.
+    ///
+    /// @param msg pointer to the packet under test.
+    /// @param start_time system time prior to or equal to the timestamp
+    /// of the stack's first event (i.e. before packet was sent or received)
+    /// @param expected_events a list of the event labels in the order they
+    /// are expected to occur in the stack.
+    void testPktEvents(const PktPtr& msg, boost::posix_time::ptime start_time,
+                       std::list<std::string> expected_events) const;
+
     std::string ifname_;   ///< Loopback interface name.
     unsigned int ifindex_; ///< Loopback interface index.
     uint16_t port_;        ///< A port number used for the test.
     isc::dhcp::SocketInfo sock_info_; ///< A structure holding socket info.
     int send_msg_sock_;    ///< Holds a descriptor of the socket used by
                            ///< sendMessage function.
+    boost::posix_time::ptime start_time_; ///< System time at the start of the test.
     Pkt6Ptr test_message_; ///< A DHCPv6 message used by tests.
 
 };
