@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -154,9 +154,14 @@ CfgSubnets4::merge(CfgOptionDefPtr cfg_def, CfgSharedNetworks4Ptr networks,
         // Create the subnet's options based on the given definitions.
         other_subnet->getCfgOption()->createOptions(cfg_def);
 
+        // Encapsulate options, so that the DHCP server can effectively return
+        // them to the clients without having to encapsulate them for each request.
+        other_subnet->getCfgOption()->encapsulate();
+
         // Create the options for pool based on the given definitions.
-        for (const auto& pool : other_subnet->getPoolsWritable(Lease::TYPE_V4)) {
+        for (auto const& pool : other_subnet->getPoolsWritable(Lease::TYPE_V4)) {
             pool->getCfgOption()->createOptions(cfg_def);
+            pool->getCfgOption()->encapsulate();
         }
 
         // Add the "other" subnet to the our collection of subnets.
@@ -183,23 +188,16 @@ CfgSubnets4::merge(CfgOptionDefPtr cfg_def, CfgSharedNetworks4Ptr networks,
     }
 }
 
-ConstSubnet4Ptr
-CfgSubnets4::getBySubnetId(const SubnetID& subnet_id) const {
-    const auto& index = subnets_.get<SubnetSubnetIdIndexTag>();
-    auto subnet_it = index.find(subnet_id);
-    return ((subnet_it != index.cend()) ? (*subnet_it) : ConstSubnet4Ptr());
-}
-
 ConstSubnet4Ptr
 CfgSubnets4::getByPrefix(const std::string& subnet_text) const {
-    const auto& index = subnets_.get<SubnetPrefixIndexTag>();
+    auto const& index = subnets_.get<SubnetPrefixIndexTag>();
     auto subnet_it = index.find(subnet_text);
     return ((subnet_it != index.cend()) ? (*subnet_it) : ConstSubnet4Ptr());
 }
 
 bool
 CfgSubnets4::hasSubnetWithServerId(const asiolink::IOAddress& server_id) const {
-    const auto& index = subnets_.get<SubnetServerIdIndexTag>();
+    auto const& index = subnets_.get<SubnetServerIdIndexTag>();
     auto subnet_it = index.find(server_id);
     return (subnet_it != index.cend());
 }
@@ -459,15 +457,10 @@ CfgSubnets4::selectSubnet(const std::string& iface,
 }
 
 Subnet4Ptr
-CfgSubnets4::getSubnet(const SubnetID id) const {
-    /// @todo: Once this code is migrated to multi-index container, use
-    /// an index rather than full scan.
-    for (auto const& subnet : subnets_) {
-        if (subnet->getID() == id) {
-            return (subnet);
-        }
-    }
-    return (Subnet4Ptr());
+CfgSubnets4::getSubnet(const SubnetID subnet_id) const {
+    auto const& index = subnets_.get<SubnetSubnetIdIndexTag>();
+    auto subnet_it = index.find(subnet_id);
+    return ((subnet_it != index.cend()) ? (*subnet_it) : Subnet4Ptr());
 }
 
 Subnet4Ptr
@@ -498,18 +491,12 @@ CfgSubnets4::selectSubnet(const IOAddress& address,
 }
 
 SubnetIDSet
-CfgSubnets4::getLinks(const IOAddress& link_addr, uint8_t& link_len) const {
+CfgSubnets4::getLinks(const IOAddress& link_addr) const {
     SubnetIDSet links;
-    bool link_len_set = false;
     for (auto const& subnet : subnets_) {
         if (!subnet->inRange(link_addr)) {
             continue;
         }
-        uint8_t plen = subnet->get().second;
-        if (!link_len_set || (plen < link_len)) {
-            link_len_set = true;
-            link_len = plen;
-        }
         links.insert(subnet->getID());
     }
     return (links);
@@ -541,7 +528,7 @@ CfgSubnets4::removeStatistics() {
         stats_mgr.del(StatsMgr::generateName("subnet", subnet_id,
                                              "reclaimed-leases"));
 
-        for (const auto& pool : subnet4->getPools(Lease::TYPE_V4)) {
+        for (auto const& pool : subnet4->getPools(Lease::TYPE_V4)) {
             stats_mgr.del(StatsMgr::generateName("subnet", subnet_id,
                                                  StatsMgr::generateName("pool", pool->getID(),
                                                                         "total-addresses")));
@@ -598,7 +585,7 @@ CfgSubnets4::updateStatistics() {
             stats_mgr.setValue(name_conflicts, static_cast<int64_t>(0));
         }
 
-        for (const auto& pool : subnet4->getPools(Lease::TYPE_V4)) {
+        for (auto const& pool : subnet4->getPools(Lease::TYPE_V4)) {
             const std::string& name_total(StatsMgr::generateName("subnet", subnet_id,
                                                                  StatsMgr::generateName("pool", pool->getID(),
                                                                                         "total-addresses")));
@@ -625,7 +612,7 @@ CfgSubnets4::updateStatistics() {
 
 void
 CfgSubnets4::initAllocatorsAfterConfigure() {
-    for (auto subnet : subnets_) {
+    for (auto const& subnet : subnets_) {
         subnet->initAllocatorsAfterConfigure();
     }
 }
