@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2019 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -6,14 +6,17 @@
 
 #include <config.h>
 
+#include <asiolink/io_address.h>
+#include <asiolink/addr_utilities.h>
+#include <cryptolink/crypto_rng.h>
 #include <dhcp/pkt4.h>
 #include <dhcpsrv/host.h>
-#include <util/encode/hex.h>
-#include <util/strutil.h>
-#include <asiolink/io_address.h>
-#include <cryptolink/crypto_rng.h>
 #include <exceptions/exceptions.h>
 
+#include <util/encode/encode.h>
+#include <util/str.h>
+
+#include <boost/foreach.hpp>
 #include <sstream>
 
 using namespace isc::data;
@@ -208,6 +211,22 @@ Host::Host(const std::string& identifier, const std::string& identifier_name,
     }
 }
 
+size_t
+Host::getIdentifierMaxLength(const IdentifierType& type) {
+    switch (type) {
+    case IDENT_HWADDR:
+        return (HWAddr::MAX_HWADDR_LEN);
+    case IDENT_DUID:
+        return (DUID::MAX_DUID_LEN);
+    case IDENT_CLIENT_ID:
+        return (ClientId::MAX_CLIENT_ID_LEN);
+    default:
+        // In fact it is backend dependent but for compatibility we take
+        // the lowest value.
+        return (128);
+    }
+}
+
 const std::vector<uint8_t>&
 Host::getIdentifier() const {
     return (identifier_value_);
@@ -319,6 +338,10 @@ Host::setIdentifier(const uint8_t* identifier, const size_t len,
                     const IdentifierType& type) {
     if (len < 1) {
         isc_throw(BadValue, "invalid client identifier length 0");
+    } else if (len > getIdentifierMaxLength(type)) {
+        isc_throw(BadValue, "too long client identifier type "
+                  << getIdentifierName(type)
+                  << " length " << len);
     }
 
     identifier_type_ = type;
@@ -343,22 +366,40 @@ Host::setIdentifier(const std::string& identifier, const std::string& name) {
     // If the identifier lacks opening and closing quote, this will return
     // an empty value, in which case we'll try to decode it as a string of
     // hexadecimal digits.
+    bool too_long = false;
     try {
         std::vector<uint8_t> binary = util::str::quotedStringToBinary(identifier);
         if (binary.empty()) {
             util::str::decodeFormattedHexString(identifier, binary);
         }
+
+        size_t len = binary.size();
+        if (len > getIdentifierMaxLength(identifier_type_)) {
+            // Message does not matter as it will be replaced below...
+            too_long = true;
+            isc_throw(BadValue, "too long client identifier type " << name
+                      << " length " << len);
+        }
+
         // Successfully decoded the identifier, so let's use it.
         identifier_value_.swap(binary);
 
     } catch (...) {
         // The string doesn't match any known pattern, so we have to
         // report an error at this point.
+        if (too_long) {
+            throw;
+        }
         isc_throw(isc::BadValue, "invalid host identifier value '"
-                      << identifier << "'");
+                  << identifier << "'");
     }
 }
 
+void
+Host::setIdentifierType(const IdentifierType& type) {
+    identifier_type_ = type;
+}
+
 void
 Host::setIPv4Reservation(const asiolink::IOAddress& address) {
     if (!address.isV4()) {
@@ -408,9 +449,8 @@ bool
 Host::hasReservation(const IPv6Resrv& reservation) const {
     IPv6ResrvRange reservations = getIPv6Reservations(reservation.getType());
     if (std::distance(reservations.first, reservations.second) > 0) {
-        for (IPv6ResrvIterator it = reservations.first;
-             it != reservations.second; ++it) {
-            if (it->second == reservation) {
+        BOOST_FOREACH(auto const& it, reservations) {
+            if (it.second == reservation) {
                 return (true);
             }
         }
@@ -521,9 +561,8 @@ Host::toElement4() const {
     // Set client-classes
     const ClientClasses& cclasses = getClientClasses4();
     ElementPtr classes = Element::createList();
-    for (ClientClasses::const_iterator cclass = cclasses.cbegin();
-         cclass != cclasses.cend(); ++cclass) {
-        classes->add(Element::create(*cclass));
+    for (auto const& cclass : cclasses) {
+        classes->add(Element::create(cclass));
     }
     map->set("client-classes", classes);
     // Set option-data
@@ -559,19 +598,17 @@ Host::toElement6() const {
         isc_throw(ToElementError, "invalid DUID type: " << id_type);
     }
     // Set reservations (ip-addresses)
-    IPv6ResrvRange na_resv = getIPv6Reservations(IPv6Resrv::TYPE_NA);
+    const IPv6ResrvRange& na_resv = getIPv6Reservations(IPv6Resrv::TYPE_NA);
     ElementPtr resvs = Element::createList();
-    for (IPv6ResrvIterator resv = na_resv.first;
-         resv != na_resv.second; ++resv) {
-        resvs->add(Element::create(resv->second.toText()));
+    BOOST_FOREACH(auto const& resv, na_resv) {
+        resvs->add(Element::create(resv.second.toText()));
     }
     map->set("ip-addresses", resvs);
     // Set reservations (prefixes)
-    IPv6ResrvRange pd_resv = getIPv6Reservations(IPv6Resrv::TYPE_PD);
+    const IPv6ResrvRange& pd_resv = getIPv6Reservations(IPv6Resrv::TYPE_PD);
     resvs = Element::createList();
-    for (IPv6ResrvIterator resv = pd_resv.first;
-         resv != pd_resv.second; ++resv) {
-        resvs->add(Element::create(resv->second.toText()));
+    BOOST_FOREACH(auto const& resv, pd_resv) {
+        resvs->add(Element::create(resv.second.toText()));
     }
     map->set("prefixes", resvs);
     // Set the hostname
@@ -580,9 +617,8 @@ Host::toElement6() const {
     // Set client-classes
     const ClientClasses& cclasses = getClientClasses6();
     ElementPtr classes = Element::createList();
-    for (ClientClasses::const_iterator cclass = cclasses.cbegin();
-         cclass != cclasses.cend(); ++cclass) {
-        classes->add(Element::create(*cclass));
+    for (auto const& cclass : cclasses) {
+        classes->add(Element::create(cclass));
     }
     map->set("client-classes", classes);
 
@@ -597,6 +633,16 @@ Host::toElement6() const {
     return (map);
 }
 
+void
+Host::encapsulateOptions() const {
+    if (!cfg_option4_->isEncapsulated()) {
+        cfg_option4_->encapsulate();
+    }
+    if (!cfg_option6_->isEncapsulated()) {
+        cfg_option6_->encapsulate();
+    }
+}
+
 std::string
 Host::toText() const {
     std::ostringstream s;
@@ -633,33 +679,35 @@ Host::toText() const {
 
     s << " key=" << (key_.toText().empty() ? "(empty)" : key_.toText());
 
+    size_t count = 0;
+
     if (ipv6_reservations_.empty()) {
         s << " ipv6_reservations=(none)";
 
     } else {
         // Add all IPv6 reservations.
-        for (IPv6ResrvIterator resrv = ipv6_reservations_.begin();
-             resrv != ipv6_reservations_.end(); ++resrv) {
+        count = 0;
+        for (auto const& resrv : ipv6_reservations_) {
             s << " ipv6_reservation"
-              << std::distance(ipv6_reservations_.begin(), resrv)
-              << "=" << resrv->second.toText();
+              << count++
+              << "=" << resrv.second.toText();
         }
     }
 
     // Add DHCPv4 client classes.
-    for (ClientClasses::const_iterator cclass = dhcp4_client_classes_.cbegin();
-         cclass != dhcp4_client_classes_.cend(); ++cclass) {
+    count = 0;
+    for (auto const& cclass : dhcp4_client_classes_) {
         s << " dhcp4_class"
-          << std::distance(dhcp4_client_classes_.cbegin(), cclass)
-          << "=" << *cclass;
+          << count++
+          << "=" << cclass;
     }
 
     // Add DHCPv6 client classes.
-    for (ClientClasses::const_iterator cclass = dhcp6_client_classes_.cbegin();
-         cclass != dhcp6_client_classes_.cend(); ++cclass) {
+    count = 0;
+    for (auto const& cclass : dhcp6_client_classes_) {
         s << " dhcp6_class"
-          << std::distance(dhcp6_client_classes_.cbegin(), cclass)
-          << "=" << *cclass;
+          << count++
+          << "=" << cclass;
     }
 
     // Add negative cached.
