@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2016-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -9,8 +9,6 @@
 #include <cc/data.h>
 #include <dhcpsrv/parsers/simple_parser6.h>
 
-#include <boost/foreach.hpp>
-
 using namespace isc::data;
 
 namespace isc {
@@ -71,7 +69,6 @@ const SimpleKeywords SimpleParser6::GLOBAL6_PARAMETERS = {
     { "reservations",                     Element::list },
     { "config-control",                   Element::map },
     { "server-tag",                       Element::string },
-    { "reservation-mode",                 Element::string },
     { "reservations-global",              Element::boolean },
     { "reservations-in-subnet",           Element::boolean },
     { "reservations-out-of-pool",         Element::boolean },
@@ -97,12 +94,12 @@ const SimpleKeywords SimpleParser6::GLOBAL6_PARAMETERS = {
     { "ip-reservations-unique",           Element::boolean },
     { "reservations-lookup-first",        Element::boolean },
     { "ddns-update-on-renew",             Element::boolean },
-    { "ddns-use-conflict-resolution",     Element::boolean },
     { "compatibility",                    Element::map },
     { "parked-packet-limit",              Element::integer },
     { "allocator",                        Element::string },
     { "pd-allocator",                     Element::string },
     { "ddns-ttl-percent",                 Element::real },
+    { "ddns-conflict-resolution-mode",    Element::string },
 };
 
 /// @brief This table defines default global values for DHCPv6
@@ -137,10 +134,10 @@ const SimpleDefaults SimpleParser6::GLOBAL6_DEFAULTS = {
     { "ip-reservations-unique",           Element::boolean, "true" },
     { "reservations-lookup-first",        Element::boolean, "false" },
     { "ddns-update-on-renew",             Element::boolean, "false" },
-    { "ddns-use-conflict-resolution",     Element::boolean, "true" },
     { "parked-packet-limit",              Element::integer, "256" },
     { "allocator",                        Element::string,  "iterative" },
     { "pd-allocator",                     Element::string,  "iterative" },
+    { "ddns-conflict-resolution-mode",    Element::string,  "check-with-dhcid" },
 };
 
 /// @brief This table defines all option definition parameters.
@@ -227,7 +224,6 @@ const SimpleKeywords SimpleParser6::SUBNET6_PARAMETERS = {
     { "client-class",                   Element::string },
     { "require-client-classes",         Element::list },
     { "reservations",                   Element::list },
-    { "reservation-mode",               Element::string },
     { "reservations-global",            Element::boolean },
     { "reservations-in-subnet",         Element::boolean },
     { "reservations-out-of-pool",       Element::boolean },
@@ -250,10 +246,10 @@ const SimpleKeywords SimpleParser6::SUBNET6_PARAMETERS = {
     { "cache-threshold",                Element::real },
     { "cache-max-age",                  Element::integer },
     { "ddns-update-on-renew",           Element::boolean },
-    { "ddns-use-conflict-resolution",   Element::boolean },
     { "allocator",                      Element::string },
     { "pd-allocator",                   Element::string },
     { "ddns-ttl-percent",               Element::real },
+    { "ddns-conflict-resolution-mode",  Element::string },
 };
 
 /// @brief This table defines default values for each IPv6 subnet.
@@ -263,7 +259,6 @@ const SimpleKeywords SimpleParser6::SUBNET6_PARAMETERS = {
 /// where a parameter can be derived from shared-networks, but is not
 /// defined on global level.
 const SimpleDefaults SimpleParser6::SUBNET6_DEFAULTS = {
-    { "id",               Element::integer, "0" }, // 0 means autogenerate
     { "interface",        Element::string,  "" },
     { "client-class",     Element::string,  "" },
     { "rapid-commit",     Element::boolean, "false" }, // rapid-commit disabled by default
@@ -276,7 +271,6 @@ const SimpleDefaults SimpleParser6::SUBNET6_DEFAULTS = {
 /// This is mostly the same as @ref SUBNET6_DEFAULTS, except the parameters
 /// that can be derived from shared-network, but cannot from global scope.
 const SimpleDefaults SimpleParser6::SHARED_SUBNET6_DEFAULTS = {
-    { "id",               Element::integer, "0" } // 0 means autogenerate
 };
 
 /// @brief This table defines default values for each IPv6 shared network.
@@ -366,7 +360,6 @@ const SimpleKeywords SimpleParser6::SHARED_NETWORK6_PARAMETERS = {
     { "rebind-timer",                   Element::integer },
     { "option-data",                    Element::list },
     { "relay",                          Element::map },
-    { "reservation-mode",               Element::string },
     { "reservations-global",            Element::boolean },
     { "reservations-in-subnet",         Element::boolean },
     { "reservations-out-of-pool",       Element::boolean },
@@ -397,10 +390,10 @@ const SimpleKeywords SimpleParser6::SHARED_NETWORK6_PARAMETERS = {
     { "cache-threshold",                Element::real },
     { "cache-max-age",                  Element::integer },
     { "ddns-update-on-renew",           Element::boolean },
-    { "ddns-use-conflict-resolution",   Element::boolean },
     { "allocator",                      Element::string },
     { "pd-allocator",                   Element::string },
     { "ddns-ttl-percent",               Element::real },
+    { "ddns-conflict-resolution-mode",  Element::string },
 };
 
 /// @brief This table defines default values for interfaces for DHCPv6.
@@ -442,7 +435,7 @@ size_t SimpleParser6::setAllDefaults(ElementPtr global) {
     // Now set the defaults for each specified option definition
     ConstElementPtr option_defs = global->get("option-def");
     if (option_defs) {
-        BOOST_FOREACH(ElementPtr option_def, option_defs->listValue()) {
+        for (auto const& option_def : option_defs->listValue()) {
             cnt += SimpleParser::setDefaults(option_def, OPTION6_DEF_DEFAULTS);
         }
     }
@@ -450,7 +443,7 @@ size_t SimpleParser6::setAllDefaults(ElementPtr global) {
     // Set the defaults for option data
     ConstElementPtr options = global->get("option-data");
     if (options) {
-        BOOST_FOREACH(ElementPtr single_option, options->listValue()) {
+        for (auto const& single_option : options->listValue()) {
             cnt += SimpleParser::setDefaults(single_option, OPTION6_DEFAULTS);
         }
     }
@@ -471,7 +464,7 @@ size_t SimpleParser6::setAllDefaults(ElementPtr global) {
     // Set defaults for shared networks
     ConstElementPtr shared = global->get("shared-networks");
     if (shared) {
-        BOOST_FOREACH(ElementPtr net, shared->listValue()) {
+        for (auto const& net : shared->listValue()) {
 
             cnt += setDefaults(net, SHARED_NETWORK6_DEFAULTS);
 
@@ -528,7 +521,7 @@ size_t SimpleParser6::deriveParameters(ElementPtr global) {
     // Now derive global parameters into subnets.
     ConstElementPtr subnets = global->get("subnet6");
     if (subnets) {
-        BOOST_FOREACH(ElementPtr single_subnet, subnets->listValue()) {
+        for (auto const& single_subnet : subnets->listValue()) {
             cnt += SimpleParser::deriveParams(global, single_subnet,
                                               INHERIT_TO_SUBNET6);
         }
@@ -539,7 +532,7 @@ size_t SimpleParser6::deriveParameters(ElementPtr global) {
     // subnets within derive from it.
     ConstElementPtr shared = global->get("shared-networks");
     if (shared) {
-        BOOST_FOREACH(ElementPtr net, shared->listValue()) {
+        for (auto const& net : shared->listValue()) {
             // First try to inherit the parameters from shared network,
             // if defined there.
             // Then try to inherit them from global.
@@ -549,7 +542,7 @@ size_t SimpleParser6::deriveParameters(ElementPtr global) {
             // Now we need to go thrugh all the subnets in this net.
             subnets = net->get("subnet6");
             if (subnets) {
-                BOOST_FOREACH(ElementPtr single_subnet, subnets->listValue()) {
+                for (auto const& single_subnet : subnets->listValue()) {
                     cnt += SimpleParser::deriveParams(net, single_subnet,
                                                       INHERIT_TO_SUBNET6);
                 }
