@@ -1,4 +1,4 @@
-// Copyright (C) 2019-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2019-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -23,6 +23,7 @@
 #include <hooks/callout_manager.h>
 #include <hooks/hooks_manager.h>
 #include <testutils/gtest_utils.h>
+#include <boost/foreach.hpp>
 #include <boost/date_time/posix_time/posix_time.hpp>
 #include <boost/make_shared.hpp>
 #include <gtest/gtest.h>
@@ -174,10 +175,10 @@ public:
     /// @param object_type Object type.
     bool hasConfigElement(const std::string& object_type) const {
         if (!audit_entries_.empty()) {
-            const auto& index = audit_entries_.get<AuditEntryObjectTypeTag>();
+            auto const& index = audit_entries_.get<AuditEntryObjectTypeTag>();
             auto range = index.equal_range(object_type);
-            for (auto it = range.first; it != range.second; ++it) {
-                if (((*it)->getModificationType() != AuditEntry::ModificationType::DELETE)) {
+            BOOST_FOREACH(auto const& it, range) {
+                if (it->getModificationType() != AuditEntry::ModificationType::DELETE) {
                     return (true);
                 }
             }
@@ -195,11 +196,11 @@ public:
     bool deleteConfigElement(const std::string& object_type,
                              const uint64_t object_id) const {
         if (!audit_entries_.empty()) {
-            const auto& index = audit_entries_.get<AuditEntryObjectTypeTag>();
+            auto const& index = audit_entries_.get<AuditEntryObjectTypeTag>();
             auto range = index.equal_range(boost::make_tuple(object_type,
                                                              AuditEntry::ModificationType::DELETE));
-            for (auto it = range.first; it != range.second; ++it) {
-                if ((*it)->getObjectId() == object_id) {
+            BOOST_FOREACH(auto const& it, range) {
+                if (it->getObjectId() == object_id) {
                     return (true);
                 }
             }
@@ -586,6 +587,7 @@ public:
             (getTimestamp("dhcp4_options") > lb_modification_time)) {
             ASSERT_TRUE(found_opt.option_);
             EXPECT_EQ("new.example.com", found_opt.option_->toString());
+            EXPECT_TRUE(options->isEncapsulated());
 
         } else {
             EXPECT_FALSE(found_opt.option_);
@@ -600,6 +602,7 @@ public:
             (getTimestamp("dhcp4_shared_network") > lb_modification_time)) {
             ASSERT_TRUE(found_network);
             EXPECT_TRUE(found_network->hasFetchGlobalsFn());
+            EXPECT_TRUE(found_network->getCfgOption()->isEncapsulated());
 
         } else {
             EXPECT_FALSE(found_network);
@@ -615,6 +618,7 @@ public:
             EXPECT_TRUE(found_subnet->hasFetchGlobalsFn());
             EXPECT_TRUE(boost::dynamic_pointer_cast<RandomAllocator>
                         (found_subnet->getAllocator(Lease::TYPE_V4)));
+            EXPECT_TRUE(found_subnet->getCfgOption()->isEncapsulated());
 
         } else {
             EXPECT_FALSE(found_subnet);
@@ -646,6 +650,9 @@ public:
             EXPECT_EQ(OptionBuffer(option_desc.formatted_value_.begin(),
                                    option_desc.formatted_value_.end()),
                       option->getData());
+
+            // Make sure that the options have been encapsulated.
+            EXPECT_TRUE(cfg_option_desc->isEncapsulated());
         } else {
             EXPECT_FALSE(found_class);
         }
@@ -1499,6 +1506,7 @@ public:
             (getTimestamp("dhcp6_options") > lb_modification_time)) {
             ASSERT_TRUE(found_opt.option_);
             EXPECT_EQ("some.bootfile", found_opt.option_->toString());
+            EXPECT_TRUE(options->isEncapsulated());
 
         } else {
             EXPECT_FALSE(found_opt.option_);
@@ -1513,6 +1521,7 @@ public:
             (getTimestamp("dhcp6_shared_network") > lb_modification_time)) {
             ASSERT_TRUE(found_network);
             EXPECT_TRUE(found_network->hasFetchGlobalsFn());
+            EXPECT_TRUE(found_network->getCfgOption()->isEncapsulated());
 
         } else {
             EXPECT_FALSE(found_network);
@@ -1530,6 +1539,7 @@ public:
             EXPECT_TRUE(boost::dynamic_pointer_cast<RandomAllocator>
                         (found_subnet->getAllocator(Lease::TYPE_PD)));
             EXPECT_TRUE(found_subnet->hasFetchGlobalsFn());
+            EXPECT_TRUE(found_subnet->getCfgOption()->isEncapsulated());
 
         } else {
             EXPECT_FALSE(found_subnet);
@@ -1553,6 +1563,8 @@ public:
             EXPECT_EQ(OptionBuffer(option_desc.formatted_value_.begin(),
                                    option_desc.formatted_value_.end()),
                       option->getData());
+            EXPECT_TRUE(found_class->getCfgOption()->isEncapsulated());
+
         } else {
             EXPECT_FALSE(found_class);
         }
