@@ -1,4 +1,4 @@
-// Copyright (C) 2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2023-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -220,6 +220,19 @@ public:
     getLeases6(const asiolink::IOAddress& /* lower_bound_address */,
                const LeasePageSize& /* page_size */) const override;
 
+    /// @brief Returns a page of IPv6 leases for a  subnet identifier.
+    ///
+    /// @param subnet_id subnet identifier.
+    /// @param lower_bound_address IPv6 address used as lower bound for the
+    /// returned range.
+    /// @param page_size maximum size of the page returned.
+    ///
+    /// @return collection of IPv6 leases
+    virtual Lease6Collection
+    getLeases6(SubnetID /* subnet_id */,
+               const asiolink::IOAddress& /* lower_bound_address */,
+               const LeasePageSize& /* page_size */) const override;
+
     /// @brief Returns expired DHCPv6 leases.
     ///
     /// This method is not implemented.
@@ -357,33 +370,26 @@ public:
     /// @brief Stub implementation.
     Lease6Collection
     getLeases6ByRelayId(const DUID& /* relay_id */,
-                        const asiolink::IOAddress& /* link_addr */,
-                        uint8_t /* link_len */,
                         const asiolink::IOAddress& /* lower_bound_address */,
                         const LeasePageSize& /* page_size */) override;
 
     /// @brief Stub implementation.
     Lease6Collection
     getLeases6ByRemoteId(const OptionBuffer& /* remote_id */,
-                         const asiolink::IOAddress& /* link_addr */,
-                         uint8_t /* link_len */,
                          const asiolink::IOAddress& /* lower_bound_address */,
                          const LeasePageSize& /* page_size*/) override;
 
-    /// @brief Stub implementation.
-    Lease6Collection
-    getLeases6ByLink(const asiolink::IOAddress& /* link_addr */,
-                     uint8_t /* link_len */,
-                     const asiolink::IOAddress& /* lower_bound_address */,
-                     const LeasePageSize& /* page_size */) override;
-
     /// @brief Stub implementation.
     virtual size_t
     upgradeExtendedInfo4(const LeasePageSize& /* page_size */) override;
 
     /// @brief Stub implementation.
-    virtual size_t buildExtendedInfoTables6(bool /* update */,
-                                            bool /* current */) override;
+    virtual size_t
+    upgradeExtendedInfo6(const LeasePageSize& /* page_size */) override;
+
+    /// @brief Stub implementation.
+    virtual void
+    wipeExtendedInfoTables6() override;
 
     ///  @brief Pretends to write V4 leases to a file.
     virtual void writeLeases4(const std::string&) override;
@@ -414,7 +420,9 @@ public:
     virtual std::string getDescription() const override;
 
     /// @brief Returns backend version.
-    virtual std::pair<uint32_t, uint32_t> getVersion() const override;
+    ///
+    /// @param timer_name The DB reconnect timer name.
+    virtual std::pair<uint32_t, uint32_t> getVersion(const std::string& /* timer_name */ = "") const override;
 
     /// @brief Commit transactions
     virtual void commit() override;
