@@ -1,4 +1,4 @@
-// Copyright (C) 2009-2018 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2009-2025 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -6,25 +6,23 @@
 
 #include <config.h>
 
+#include <exceptions/isc_assert.h>
+#include <dns/name.h>
+#include <dns/name_internal.h>
+#include <dns/messagerenderer.h>
+#include <dns/labelsequence.h>
+
 #include <cctype>
-#include <cassert>
 #include <iterator>
 #include <functional>
 #include <vector>
 #include <iostream>
 #include <algorithm>
 
-#include <util/buffer.h>
-#include <dns/exceptions.h>
-#include <dns/name.h>
-#include <dns/name_internal.h>
-#include <dns/messagerenderer.h>
-#include <dns/labelsequence.h>
+using namespace isc::util;
+using namespace isc::dns::name::internal;
 
 using namespace std;
-using namespace isc::util;
-using isc::dns::NameComparisonResult;
-using namespace isc::dns::name::internal;
 
 namespace isc {
 namespace dns {
@@ -189,7 +187,7 @@ stringParse(Iterator s, Iterator send, bool downcase, Offsets& offsets,
                 break;
             }
             state = ft_ordinary;
-            assert(ndata.size() < Name::MAX_WIRE);
+            isc_throw_assert(ndata.size() < Name::MAX_WIRE);
             // FALLTHROUGH
         case ft_ordinary:
             if (c == '.') {
@@ -261,7 +259,7 @@ stringParse(Iterator s, Iterator send, bool downcase, Offsets& offsets,
             break;
         default:
             // impossible case
-            assert(false);
+            isc_throw_assert(false);
         }
     }
 
@@ -271,14 +269,14 @@ stringParse(Iterator s, Iterator send, bool downcase, Offsets& offsets,
                       "name is too long for termination in " <<
                       string(orig_s, send));
         }
-        assert(s == send);
+        isc_throw_assert(s == send);
         if (state != ft_ordinary) {
             isc_throw(IncompleteName,
                       "incomplete textual name in " <<
                       (empty ? "<empty>" : string(orig_s, send)));
         }
         if (state == ft_ordinary) {
-            assert(count != 0);
+            isc_throw_assert(count != 0);
             ndata.at(offsets.back()) = count;
 
             offsets.push_back(ndata.size());
@@ -304,17 +302,16 @@ Name::Name(const std::string &namestring, bool downcase) {
 
     // And get the output
     labelcount_ = offsets.size();
-    assert(labelcount_ > 0 && labelcount_ <= Name::MAX_LABELS);
-    ndata_.assign(ndata.data(), ndata.size());
+    isc_throw_assert(labelcount_ > 0 && labelcount_ <= Name::MAX_LABELS);
+    ndata_.assign(ndata.data(), ndata.data() + ndata.size());
     length_ = ndata_.size();
     offsets_.assign(offsets.begin(), offsets.end());
 }
 
 Name::Name(const char* namedata, size_t data_len, const Name* origin,
-           bool downcase)
-{
+           bool downcase) {
     // Check validity of data
-    if (namedata == NULL || data_len == 0) {
+    if (!namedata || data_len == 0) {
         isc_throw(isc::InvalidParameter,
                   "No data provided to Name constructor");
     }
@@ -322,7 +319,7 @@ Name::Name(const char* namedata, size_t data_len, const Name* origin,
     // It is safe to check now, we know there's at least one character.
     const bool absolute = (namedata[data_len - 1] == '.');
     // If we are not absolute, we need the origin to complete the name.
-    if (!absolute && origin == NULL) {
+    if (!absolute && !origin) {
         isc_throw(MissingNameOrigin,
                   "No origin available and name is relative");
     }
@@ -338,8 +335,8 @@ Name::Name(const char* namedata, size_t data_len, const Name* origin,
 
     // Get the output
     labelcount_ = offsets.size();
-    assert(labelcount_ > 0 && labelcount_ <= Name::MAX_LABELS);
-    ndata_.assign(ndata.data(), ndata.size());
+    isc_throw_assert(labelcount_ > 0 && labelcount_ <= Name::MAX_LABELS);
+    ndata_.assign(ndata.data(), ndata.data() + ndata.size());
     length_ = ndata_.size();
     offsets_.assign(offsets.begin(), offsets.end());
 
@@ -350,7 +347,7 @@ Name::Name(const char* namedata, size_t data_len, const Name* origin,
         // Drop the last character of the data (the \0) and append a copy of
         // the origin's data
         ndata_.erase(ndata_.end() - 1);
-        ndata_.append(origin->ndata_);
+        ndata_.insert(ndata_.end(), origin->ndata_.begin(), origin->ndata_.end());
 
         // Do a similar thing with offsets. However, we need to move them
         // so they point after the prefix we parsed before.
@@ -359,8 +356,7 @@ Name::Name(const char* namedata, size_t data_len, const Name* origin,
         size_t offset_count = offsets_.size();
         offsets_.insert(offsets_.end(), origin->offsets_.begin(),
                         origin->offsets_.end());
-        for (NameOffsets::iterator it(offsets_.begin() + offset_count);
-             it != offsets_.end(); ++it) {
+        for (auto it(offsets_.begin() + offset_count); it != offsets_.end(); ++it) {
             *it += offset;
         }
 
@@ -479,7 +475,7 @@ Name::Name(InputBuffer& buffer, bool downcase) {
             state = fw_start;
             break;
         default:
-            assert(false);
+            isc_throw_assert(false);
         }
     }
 
@@ -576,8 +572,8 @@ Name::isWildcard() const {
 
 Name
 Name::concatenate(const Name& suffix) const {
-    assert(length_ > 0 && suffix.length_ > 0);
-    assert(labelcount_ > 0 && suffix.labelcount_ > 0);
+    isc_throw_assert(length_ > 0 && suffix.length_ > 0);
+    isc_throw_assert(labelcount_ > 0 && suffix.labelcount_ > 0);
 
     unsigned int length = length_ + suffix.length_ - 1;
     if (length > Name::MAX_WIRE) {
@@ -586,10 +582,10 @@ Name::concatenate(const Name& suffix) const {
 
     Name retname;
     retname.ndata_.reserve(length);
-    retname.ndata_.assign(ndata_, 0, length_ - 1);
+    retname.ndata_.assign(ndata_.data(), ndata_.data() + length_ - 1);
     retname.ndata_.insert(retname.ndata_.end(),
                           suffix.ndata_.begin(), suffix.ndata_.end());
-    assert(retname.ndata_.size() == length);
+    isc_throw_assert(retname.ndata_.size() == length);
     retname.length_ = length;
 
     //
@@ -598,13 +594,13 @@ Name::concatenate(const Name& suffix) const {
     // suffix name with the additional offset of the length of the prefix.
     //
     unsigned int labels = labelcount_ + suffix.labelcount_ - 1;
-    assert(labels <= Name::MAX_LABELS);
+    isc_throw_assert(labels <= Name::MAX_LABELS);
     retname.offsets_.reserve(labels);
     retname.offsets_.assign(&offsets_[0], &offsets_[0] + labelcount_ - 1);
     transform(suffix.offsets_.begin(), suffix.offsets_.end(),
               back_inserter(retname.offsets_),
-              bind2nd(plus<char>(), length_ - 1));
-    assert(retname.offsets_.size() == labels);
+              [this] (char x) { return (x + length_ - 1); });
+    isc_throw_assert(retname.offsets_.size() == labels);
     retname.labelcount_ = labels;
 
     return (retname);
@@ -626,7 +622,7 @@ Name::reverse() const {
     NameString::const_iterator n0 = ndata_.begin();
     retname.offsets_.push_back(0);
     while (rit1 != offsets_.rend()) {
-        retname.ndata_.append(n0 + *rit1, n0 + *rit0);
+        retname.ndata_.insert(retname.ndata_.end(), n0 + *rit1, n0 + *rit0);
         retname.offsets_.push_back(retname.ndata_.size());
         ++rit0;
         ++rit1;
@@ -657,7 +653,7 @@ Name::split(const unsigned int first, const unsigned int n) const {
     retname.offsets_.reserve(newlabels);
     transform(offsets_.begin() + first, offsets_.begin() + first + newlabels,
               back_inserter(retname.offsets_),
-              bind2nd(plus<char>(), -offsets_[first]));
+              [&](char x) { return (x - offsets_[first]); });
 
     //
     // Set up the new name.  At this point the tail of the new offsets specifies
@@ -666,12 +662,13 @@ Name::split(const unsigned int first, const unsigned int n) const {
     // original name, and append the trailing dot explicitly.
     //
     retname.ndata_.reserve(retname.offsets_.back() + 1);
-    retname.ndata_.assign(ndata_, offsets_[first], retname.offsets_.back());
+    auto it = ndata_.data() + offsets_[first];
+    retname.ndata_.assign(it, it + retname.offsets_.back());
     retname.ndata_.push_back(0);
 
     retname.length_ = retname.ndata_.size();
     retname.labelcount_ = retname.offsets_.size();
-    assert(retname.labelcount_ == newlabels);
+    isc_throw_assert(retname.labelcount_ == newlabels);
 
     return (retname);
 }
@@ -699,8 +696,8 @@ Name::downcase() {
         // we assume a valid name, and do abort() if the assumption fails
         // rather than throwing an exception.
         unsigned int count = ndata_.at(pos++);
-        assert(count <= MAX_LABELLEN);
-        assert(nlen >= count);
+        isc_throw_assert(count <= MAX_LABELLEN);
+        isc_throw_assert(nlen >= count);
 
         while (count > 0) {
             ndata_.at(pos) =
