@@ -1,4 +1,4 @@
-// Copyright (C) 2011-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -39,7 +39,7 @@ protected:
     TSIGRecordTest() :
         test_name("www.example.com"), test_mac(16, 0xda),
         test_rdata(TSIG(TSIGKey::HMACMD5_NAME(), 0x4da8877a, TSIGContext::DEFAULT_FUDGE,
-                        test_mac.size(), &test_mac[0], 0x2d65, 0, 0, NULL)),
+                        test_mac.size(), &test_mac[0], 0x2d65, 0, 0, 0)),
         test_record(test_name, test_rdata),
         buffer(0) {
     }
