@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2018 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2016-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -6,16 +6,14 @@
 
 #include <config.h>
 
-#include <log/logger_support.h>
-#include <http/http_log.h>
 #include <gtest/gtest.h>
 
+#include <util/unittests/run_all.h>
+#include <log/logger_support.h>
+
 int
 main(int argc, char* argv[]) {
     ::testing::InitGoogleTest(&argc, argv);
     isc::log::initLogger();
-
-    int result = RUN_ALL_TESTS();
-
-    return (result);
+    return (isc::util::unittests::run_all());
 }
