@@ -1,4 +1,4 @@
-// Copyright (C) 2017-2022 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2017-2025 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -40,7 +40,6 @@ using namespace isc::data;
 using namespace isc::http;
 using namespace isc::http::test;
 using namespace isc::util;
-namespace ph = std::placeholders;
 
 /// @todo: put the common part of client and server tests in its own file(s).
 
@@ -49,9 +48,6 @@ namespace {
 /// @brief IP address to which HTTP service is bound.
 const std::string SERVER_ADDRESS = "127.0.0.1";
 
-/// @brief IPv6 address to whch HTTP service is bound.
-const std::string IPV6_SERVER_ADDRESS = "::1";
-
 /// @brief Port number to which HTTP service is bound.
 const unsigned short SERVER_PORT = 18123;
 
@@ -61,10 +57,6 @@ const long REQUEST_TIMEOUT = 10000;
 /// @brief Persistent connection idle timeout used in most of the tests (ms).
 const long IDLE_TIMEOUT = 10000;
 
-/// @brief Persistent connection idle timeout used in tests where idle connections
-/// are tested (ms).
-const long SHORT_IDLE_TIMEOUT = 200;
-
 /// @brief Test timeout (ms).
 const long TEST_TIMEOUT = 10000;
 
@@ -212,7 +204,7 @@ template<typename HttpConnectionType>
 class HttpListenerImplCustom : public HttpListenerImpl {
 public:
 
-    HttpListenerImplCustom(IOService& io_service,
+    HttpListenerImplCustom(const IOServicePtr& io_service,
                            const IOAddress& server_address,
                            const unsigned short server_port,
                            const TlsContextPtr& tls_context,
@@ -276,7 +268,7 @@ public:
     ///
     /// @throw HttpListenerError when any of the specified parameters is
     /// invalid.
-    HttpListenerCustom(IOService& io_service,
+    HttpListenerCustom(const IOServicePtr& io_service,
                        const IOAddress& server_address,
                        const unsigned short server_port,
                        const TlsContextPtr& tls_context,
@@ -314,7 +306,7 @@ public:
     /// @param request_timeout Configured timeout for a HTTP request.
     /// @param idle_timeout Timeout after which persistent HTTP connection is
     /// closed by the server.
-    HttpConnectionLongWriteBuffer(IOService& io_service,
+    HttpConnectionLongWriteBuffer(const IOServicePtr& io_service,
                                   const HttpAcceptorPtr& acceptor,
                                   const TlsContextPtr& tls_context,
                                   HttpConnectionPool& connection_pool,
@@ -361,7 +353,7 @@ public:
     /// @param request_timeout Configured timeout for a HTTP request.
     /// @param idle_timeout Timeout after which persistent HTTP connection is
     /// closed by the server.
-    HttpConnectionTransactionChange(IOService& io_service,
+    HttpConnectionTransactionChange(const IOServicePtr& io_service,
                                     const HttpAcceptorPtr& acceptor,
                                     const TlsContextPtr& tls_context,
                                     HttpConnectionPool& connection_pool,
@@ -406,10 +398,9 @@ public:
     ///
     /// @param io_service IO service to be stopped on error.
     /// @param tls_context TLS context.
-    TestHttpClient(IOService& io_service, TlsContextPtr tls_context)
-        : io_service_(io_service.get_io_service()),
-          stream_(io_service_, tls_context->getContext()),
-          buf_(), response_() {
+    TestHttpClient(const IOServicePtr& io_service, TlsContextPtr tls_context)
+        : io_service_(io_service), stream_(io_service_->getInternalIOService(),
+          tls_context->getContext()), buf_(), response_() {
     }
 
     /// @brief Destructor.
@@ -423,8 +414,7 @@ public:
     ///
     /// @param request HTTP request in the textual format.
     void startRequest(const std::string& request) {
-        tcp::endpoint endpoint(address::from_string(SERVER_ADDRESS),
-                               SERVER_PORT);
+        tcp::endpoint endpoint(make_address(SERVER_ADDRESS), SERVER_PORT);
         stream_.lowest_layer().async_connect(endpoint,
         [this, request](const boost::system::error_code& ec) {
             if (ec) {
@@ -438,7 +428,7 @@ public:
                 if (ec.value() != boost::asio::error::in_progress) {
                     ADD_FAILURE() << "error occurred while connecting: "
                                   << ec.message();
-                    io_service_.stop();
+                    io_service_->stop();
                     return;
                 }
             }
@@ -447,7 +437,7 @@ public:
                 if (ec) {
                     ADD_FAILURE() << "error occurred during handshake: "
                                   << ec.message();
-                    io_service_.stop();
+                    io_service_->stop();
                     return;
                 }
                 sendRequest(request);
@@ -483,7 +473,7 @@ public:
                 } else {
                     ADD_FAILURE() << "error occurred while connecting: "
                                   << ec.message();
-                    io_service_.stop();
+                    io_service_->stop();
                     return;
                 }
             }
@@ -526,7 +516,7 @@ public:
                     // Error occurred, bail...
                     ADD_FAILURE() << "error occurred while receiving HTTP"
                         " response from the server: " << ec.message();
-                    io_service_.stop();
+                    io_service_->stop();
                 }
             }
 
@@ -538,7 +528,7 @@ public:
             // Two consecutive new lines end the part of the response we're
             // expecting.
             if (response_.find("\r\n\r\n", 0) != std::string::npos) {
-                io_service_.stop();
+                io_service_->stop();
 
             } else {
                 receivePartialResponse();
@@ -620,8 +610,8 @@ public:
 
 private:
 
-    /// @brief Holds reference to the IO service.
-    boost::asio::io_service& io_service_;
+    /// @brief Holds pointer to the IO service.
+    isc::asiolink::IOServicePtr io_service_;
 
     /// @brief A socket used for the connection.
     TlsStreamImpl stream_;
@@ -644,7 +634,7 @@ public:
     ///
     /// Starts test timer which detects timeouts.
     HttpsListenerTest()
-        : io_service_(), factory_(new TestHttpResponseCreatorFactory()),
+        : io_service_(new IOService()), factory_(new TestHttpResponseCreatorFactory()),
           test_timer_(io_service_), run_io_service_timer_(io_service_),
           clients_(), server_context_(), client_context_() {
         configServer(server_context_);
@@ -657,10 +647,11 @@ public:
     ///
     /// Removes active HTTP clients.
     virtual ~HttpsListenerTest() {
-        for (auto client = clients_.begin(); client != clients_.end();
-             ++client) {
-            (*client)->close();
+        for (auto const& client : clients_) {
+            client->close();
         }
+        test_timer_.cancel();
+        io_service_->stopAndPoll();
     }
 
     /// @brief Connect to the endpoint.
@@ -685,7 +676,7 @@ public:
         if (fail_on_timeout) {
             ADD_FAILURE() << "Timeout occurred while running the test!";
         }
-        io_service_.stop();
+        io_service_->stop();
     }
 
     /// @brief Runs IO service with optional timeout.
@@ -693,16 +684,16 @@ public:
     /// @param timeout Optional value specifying for how long the io service
     /// should be ran.
     void runIOService(long timeout = 0) {
-        io_service_.get_io_service().reset();
+        io_service_->stop();
+        io_service_->restart();
 
         if (timeout > 0) {
             run_io_service_timer_.setup(std::bind(&HttpsListenerTest::timeoutHandler,
                                                   this, false),
                                         timeout, IntervalTimer::ONE_SHOT);
         }
-        io_service_.run();
-        io_service_.get_io_service().reset();
-        io_service_.poll();
+        io_service_->run();
+        io_service_->stopAndPoll(false);
     }
 
     /// @brief Returns HTTP OK response expected by unit tests.
@@ -804,7 +795,7 @@ public:
     }
 
     /// @brief IO service used in the tests.
-    IOService io_service_;
+    IOServicePtr io_service_;
 
     /// @brief Pointer to the response creator factory.
     HttpResponseCreatorFactoryPtr factory_;
@@ -849,7 +840,7 @@ TEST_F(HttpsListenerTest, listen) {
     EXPECT_EQ(httpOk(HttpVersion::HTTP_11()), client->getResponse());
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 
@@ -901,7 +892,7 @@ TEST_F(HttpsListenerTest, keepAlive) {
     EXPECT_TRUE(client->isConnectionClosed());
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 // This test verifies that persistent HTTP connection is established by default
@@ -950,7 +941,7 @@ TEST_F(HttpsListenerTest, persistentConnection) {
     EXPECT_TRUE(client->isConnectionClosed());
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 // This test verifies that "keep-alive" connection is closed by the server after
@@ -1009,7 +1000,7 @@ TEST_F(HttpsListenerTest, keepAliveTimeout) {
     EXPECT_TRUE(client->isConnectionClosed());
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 // This test verifies that persistent connection is closed by the server after
@@ -1066,7 +1057,7 @@ TEST_F(HttpsListenerTest, persistentConnectionTimeout) {
     EXPECT_TRUE(client->isConnectionClosed());
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 // This test verifies that HTTP/1.1 connection remains open even if there is an
@@ -1119,7 +1110,7 @@ TEST_F(HttpsListenerTest, persistentConnectionBadBody) {
     EXPECT_TRUE(client->isConnectionClosed());
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 // This test verifies that the HTTP listener can't be started twice.
@@ -1194,11 +1185,10 @@ TEST_F(HttpsListenerTest, invalidIdleTimeout) {
 // This test verifies that listener can't be bound to the port to which
 // other server is bound.
 TEST_F(HttpsListenerTest, addressInUse) {
-    tcp::acceptor acceptor(io_service_.get_io_service());
+    tcp::acceptor acceptor(io_service_->getInternalIOService());
     // Use other port than SERVER_PORT to make sure that this TCP connection
     // doesn't affect subsequent tests.
-    tcp::endpoint endpoint(address::from_string(SERVER_ADDRESS),
-                           SERVER_PORT + 1);
+    tcp::endpoint endpoint(make_address(SERVER_ADDRESS), SERVER_PORT + 1);
     acceptor.open(endpoint.protocol());
     acceptor.bind(endpoint);
 
