@@ -1,4 +1,4 @@
-// Copyright (C) 2011-2016 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -21,8 +21,8 @@
 
 #include <exceptions/exceptions.h>
 
-#include <util/filename.h>
-#include <util/strutil.h>
+#include <util/filesystem.h>
+#include <util/str.h>
 
 #include <log/log_messages.h>
 #include <log/message_dictionary.h>
@@ -31,11 +31,10 @@
 
 #include <log/logger.h>
 
-#include <boost/foreach.hpp>
-
 using namespace std;
 using namespace isc::log;
 using namespace isc::util;
+using namespace isc::util::file;
 
 /// \file log/compiler/message.cc
 /// \brief Message Compiler
@@ -60,7 +59,6 @@ using namespace isc::util;
 /// help message (and exits). -d &lt;dir&gt; will make it write the
 /// output file(s) to dir instead of current working directory
 
-
 /// \brief Print Version
 ///
 /// Prints the program's version number.
@@ -86,50 +84,25 @@ usage() {
         "<message-file> is the name of the input message file.\n";
 }
 
-
-/// \brief Create Time
-///
-/// Returns the current time as a suitably-formatted string.
-///
-/// \return Current time
-
-string
-currentTime() {
-
-    // Get a text representation of the current time.
-    time_t curtime;
-    time(&curtime);
-    struct tm* timeinfo;
-    timeinfo = localtime(&curtime);
-
-    char buffer[80];
-    strftime(buffer, 80, "%a %b %d %Y %H:%M", timeinfo);
-
-    return (std::string(buffer));
-}
-
-
 /// \brief Create Header Sentinel
 ///
 /// Given the name of a file, create an \#ifdef sentinel name.  The name is
 /// &lt;name&gt;_&lt;ext&gt;, where &lt;name&gt; is the name of the file, and &lt;ext&gt;
 /// is the extension less the leading period.  The sentinel will be upper-case.
 ///
-/// \param file Filename object representing the file.
+/// \param file path to the file.
 ///
 /// \return Sentinel name
 
 string
-sentinel(Filename& file) {
-
-    string name = file.name();
+sentinel(Path& file) {
+    string name = file.stem();
     string ext = file.extension();
     string sentinel_text = name + "_" + ext.substr(1);
-    isc::util::str::uppercase(sentinel_text);
+    str::uppercase(sentinel_text);
     return (sentinel_text);
 }
 
-
 /// \brief Quote String
 ///
 /// Inserts an escape character (a backslash) prior to any double quote
@@ -156,7 +129,6 @@ quoteString(const string& instring) {
     return (outstring);
 }
 
-
 /// \brief Sorted Identifiers
 ///
 /// Given a dictionary, return a vector holding the message IDs in sorted
@@ -170,16 +142,14 @@ vector<string>
 sortedIdentifiers(MessageDictionary& dictionary) {
     vector<string> ident;
 
-    for (MessageDictionary::const_iterator i = dictionary.begin();
-         i != dictionary.end(); ++i) {
-        ident.push_back(i->first);
+    for (auto const& i : dictionary) {
+        ident.push_back(i.first);
     }
     sort(ident.begin(), ident.end());
 
     return (ident);
 }
 
-
 /// \brief Split Namespace
 ///
 /// The $NAMESPACE directive may well specify a namespace in the form a::b.
@@ -206,10 +176,9 @@ splitNamespace(string ns) {
 
     // ... and return the vector of namespace components split on the single
     // colon.
-    return (isc::util::str::tokens(ns, ":"));
+    return (str::tokens(ns, ":"));
 }
 
-
 /// \brief Write Opening Namespace(s)
 ///
 /// Writes the lines listing the namespaces in use.
@@ -225,7 +194,6 @@ writeOpeningNamespace(ostream& output, const vector<string>& ns) {
     }
 }
 
-
 /// \brief Write Closing Namespace(s)
 ///
 /// Writes the lines listing the namespaces in use.
@@ -254,15 +222,15 @@ writeClosingNamespace(ostream& output, const vector<string>& ns) {
 /// \param output_directory if not null NULL, output files are written
 ///     to the given directory. If NULL, they are written to the current
 ///     working directory.
-
 void
-writeHeaderFile(const string& file, const vector<string>& ns_components,
-                MessageDictionary& dictionary, const char* output_directory)
-{
-    Filename message_file(file);
-    Filename header_file(Filename(message_file.name()).useAsDefault(".h"));
+writeHeaderFile(const string& file,
+                const vector<string>& ns_components,
+                MessageDictionary& dictionary,
+                const char* output_directory) {
+    Path message_file(file);
+    Path header_file(Path(file).replaceExtension(".h"));
     if (output_directory != NULL) {
-        header_file.setDirectory(output_directory);
+        header_file.replaceParentPath(output_directory);
     }
 
     // Text to use as the sentinels.
@@ -272,11 +240,11 @@ writeHeaderFile(const string& file, const vector<string>& ns_components,
     errno = 0;
 
     // Open the output file for writing
-    ofstream hfile(header_file.fullName().c_str());
+    ofstream hfile(header_file.str());
 
     if (hfile.fail()) {
         isc_throw_4(MessageException, "Failed to open output file",
-                    LOG_OPEN_OUTPUT_FAIL, header_file.fullName(),
+                    LOG_OPEN_OUTPUT_FAIL, header_file.str(),
                     strerror(errno), 0);
     }
 
@@ -284,8 +252,7 @@ writeHeaderFile(const string& file, const vector<string>& ns_components,
     // after the last write.
 
     hfile <<
-        "// File created from " << message_file.fullName() << " on " <<
-            currentTime() << "\n" <<
+        "// File created from " << message_file.str() << "\n" <<
          "\n" <<
          "#ifndef " << sentinel_text << "\n" <<
          "#define "  << sentinel_text << "\n" <<
@@ -297,9 +264,8 @@ writeHeaderFile(const string& file, const vector<string>& ns_components,
     writeOpeningNamespace(hfile, ns_components);
 
     vector<string> idents = sortedIdentifiers(dictionary);
-    for (vector<string>::const_iterator j = idents.begin();
-        j != idents.end(); ++j) {
-        hfile << "extern const isc::log::MessageID " << *j << ";\n";
+    for (auto const& j : idents) {
+        hfile << "extern const isc::log::MessageID " << j << ";\n";
     }
     hfile << "\n";
 
@@ -311,24 +277,21 @@ writeHeaderFile(const string& file, const vector<string>& ns_components,
     // Report errors (if any) and exit
     if (hfile.fail()) {
         isc_throw_4(MessageException, "Error writing to output file",
-                    LOG_WRITE_ERROR, header_file.fullName(), strerror(errno),
+                    LOG_WRITE_ERROR, header_file.str(), strerror(errno),
                     0);
     }
 
     hfile.close();
 }
 
-
 /// \brief Convert Non Alpha-Numeric Characters to Underscores
 ///
 /// Simple function for use in a call to transform
-
 char
 replaceNonAlphaNum(char c) {
     return (isalnum(c) ? c : '_');
 }
 
-
 /// \brief Write Program File
 ///
 /// Writes the C++ source code file.  This defines the text of the message
@@ -363,25 +326,25 @@ replaceNonAlphaNum(char c) {
 ///     to the given directory. If NULL, they are written to the current
 ///     working directory.
 void
-writeProgramFile(const string& file, const vector<string>& ns_components,
+writeProgramFile(const string& file,
+                 const vector<string>& ns_components,
                  MessageDictionary& dictionary,
-                 const char* output_directory)
-{
-    Filename message_file(file);
-    Filename program_file(Filename(message_file.name()).useAsDefault(".cc"));
+                 const char* output_directory) {
+    Path message_file(file);
+    Path program_file(Path(file).replaceExtension(".cc"));
     if (output_directory) {
-        program_file.setDirectory(output_directory);
+        program_file.replaceParentPath(output_directory);
     }
 
     // zero out the errno to be safe
     errno = 0;
 
     // Open the output file for writing
-    ofstream ccfile(program_file.fullName().c_str());
+    ofstream ccfile(program_file.str());
 
     if (ccfile.fail()) {
         isc_throw_4(MessageException, "Error opening output file",
-                    LOG_OPEN_OUTPUT_FAIL, program_file.fullName(),
+                    LOG_OPEN_OUTPUT_FAIL, program_file.str(),
                     strerror(errno), 0);
     }
 
@@ -389,8 +352,7 @@ writeProgramFile(const string& file, const vector<string>& ns_components,
     // the last write.
 
     ccfile <<
-        "// File created from " << message_file.fullName() << " on " <<
-            currentTime() << "\n" <<
+        "// File created from " << message_file.str() << "\n" <<
          "\n" <<
          "#include <cstddef>\n" <<
          "#include <log/message_types.h>\n" <<
@@ -402,10 +364,9 @@ writeProgramFile(const string& file, const vector<string>& ns_components,
     writeOpeningNamespace(ccfile, ns_components);
 
     vector<string> idents = sortedIdentifiers(dictionary);
-    for (vector<string>::const_iterator j = idents.begin();
-        j != idents.end(); ++j) {
-        ccfile << "extern const isc::log::MessageID " << *j <<
-            " = \"" << *j << "\";\n";
+    for (auto const& j : idents) {
+        ccfile << "extern const isc::log::MessageID " << j <<
+            " = \"" << j << "\";\n";
     }
     ccfile << "\n";
 
@@ -420,13 +381,10 @@ writeProgramFile(const string& file, const vector<string>& ns_components,
 
     // Output the identifiers and the associated text.
     idents = sortedIdentifiers(dictionary);
-    for (vector<string>::const_iterator i = idents.begin();
-        i != idents.end(); ++i) {
-            ccfile << "    \"" << *i << "\", \"" <<
-                quoteString(dictionary.getText(*i)) << "\",\n";
+    for (auto const& i : idents) {
+        ccfile << "    \"" << i << "\", \"" << quoteString(dictionary.getText(i)) << "\",\n";
     }
 
-
     // ... and the postamble
     ccfile <<
         "    NULL\n" <<
@@ -440,21 +398,19 @@ writeProgramFile(const string& file, const vector<string>& ns_components,
     // Report errors (if any) and exit
     if (ccfile.fail()) {
         isc_throw_4(MessageException, "Error writing to output file",
-                    LOG_WRITE_ERROR, program_file.fullName(), strerror(errno),
+                    LOG_WRITE_ERROR, program_file.str(), strerror(errno),
                     0);
     }
 
     ccfile.close();
 }
 
-
 /// \brief Error and exit if there are duplicate entries
 ///
 /// If the input file contained duplicate message IDs, we print an
 /// error for each of them, then exit the program with a non-0 value.
 ///
 /// \param reader Message Reader used to read the file
-
 void
 errorDuplicates(MessageReader& reader) {
 
@@ -468,20 +424,18 @@ errorDuplicates(MessageReader& reader) {
         sort(duplicates.begin(), duplicates.end());
         MessageReader::MessageIDCollection::iterator new_end =
             unique(duplicates.begin(), duplicates.end());
-        for (MessageReader::MessageIDCollection::iterator i = duplicates.begin();
-            i != new_end; ++i) {
-            cout << "    " << *i << "\n";
+        duplicates.erase(new_end, duplicates.end());
+        for (auto const& i : duplicates) {
+            cout << "    " << i << "\n";
         }
         exit(1);
     }
 }
 
-
 /// \brief Main Program
 ///
 /// Parses the options then dispatches to the appropriate function.  See the
 /// main file header for the invocation.
-
 int
 main(int argc, char* argv[]) {
 
@@ -549,8 +503,7 @@ main(int argc, char* argv[]) {
         writeProgramFile(message_file, ns_components, dictionary,
                          output_directory);
 
-    }
-    catch (const MessageException& e) {
+    } catch (const MessageException& e) {
         // Create an error message from the ID and the text
         const MessageDictionaryPtr& global = MessageDictionary::globalDictionary();
         string text = e.id();
@@ -560,7 +513,7 @@ main(int argc, char* argv[]) {
         vector<string> args(e.arguments());
         for (size_t i(0); i < args.size(); ++ i) {
             try {
-                replacePlaceholder(&text, args[i], i + 1);
+                replacePlaceholder(text, args[i], i + 1);
             } catch (...) {
                 // Error in error handling: nothing right to do...
             }
@@ -568,9 +521,16 @@ main(int argc, char* argv[]) {
 
         cerr << text << "\n";
 
+        return (1);
+    } catch (const std::exception& ex) {
+        cerr << "Fatal error: " << ex.what() << "\n";
+
+        return (1);
+    } catch (...) {
+        cerr << "Fatal error\n";
+
         return (1);
     }
 
     return (0);
-
 }
