@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2019 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2022 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -19,7 +19,7 @@ using namespace isc::util;
 
 // Verifies initializing via an access string and unparsing into elements
 // We just test basic unparsing, as more rigorous testing is done in
-// libkea-db testing which ConfibDBInfo uses.
+// libkea-db testing which ConfigDBInfo uses.
 TEST(ConfigDbInfo, basicOperation) {
     ConfigDbInfo db;
     std::string access = "type=mysql user=tom password=terrific";
@@ -144,7 +144,7 @@ TEST(ConfigControlInfo, basicOperation) {
     EXPECT_FALSE(db_info2 == ConfigControlInfo::EMPTY_DB());
     EXPECT_EQ (access_str2, db_info2.getAccessString());
 
-    // Verify not finding a db reutrns EMPTY_DB().
+    // Verify not finding a db returns EMPTY_DB().
     const ConfigDbInfo& db_info3 = ctl.findConfigDb("type", "bogus");
     EXPECT_TRUE(db_info3 == ConfigControlInfo::EMPTY_DB());
 
@@ -172,7 +172,7 @@ TEST(ConfigControlInfo, copyAndEquality) {
 
     // Make a third instance with a different db.
     ConfigControlInfo ctl3;
-    ASSERT_NO_THROW(ctl1.addConfigDatabase("type=cql host=other.org"));
+    ASSERT_NO_THROW(ctl1.addConfigDatabase("type=mysql host=other.org"));
 
     // They should not equal.
     EXPECT_FALSE(ctl3.equals(ctl1));
