@@ -1,4 +1,4 @@
-// Copyright (C) 2015-2019 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -9,9 +9,13 @@
 
 #include <stats/observation.h>
 #include <stats/context.h>
+#include <util/bigints.h>
+
 #include <boost/noncopyable.hpp>
+#include <boost/scoped_ptr.hpp>
 
 #include <map>
+#include <mutex>
 #include <string>
 #include <vector>
 #include <sstream>
@@ -59,7 +63,7 @@ namespace stats {
 /// for adding logging have been marked in @ref addValueInternal and
 /// @ref setValueInternal.
 class StatsMgr : public boost::noncopyable {
- public:
+public:
 
     /// @brief Statistics Manager accessor method.
     static StatsMgr& instance();
@@ -77,6 +81,13 @@ class StatsMgr : public boost::noncopyable {
     /// @throw InvalidStatType if statistic is not integer
     void setValue(const std::string& name, const int64_t value);
 
+    /// @brief Records an absolute big integer observation.
+    ///
+    /// @param name name of the observation
+    /// @param value integer value observed
+    /// @throw InvalidStatType if statistic is not integer
+    void setValue(const std::string& name, const isc::util::int128_t& value);
+
     /// @brief Records absolute floating point observation.
     ///
     /// @param name name of the observation
@@ -105,6 +116,13 @@ class StatsMgr : public boost::noncopyable {
     /// @throw InvalidStatType if statistic is not integer
     void addValue(const std::string& name, const int64_t value);
 
+    /// @brief Records an incremental big integer observation.
+    ///
+    /// @param name name of the observation
+    /// @param value integer value observed
+    /// @throw InvalidStatType if statistic is not integer
+    void addValue(const std::string& name, const isc::util::int128_t& value);
+
     /// @brief Records incremental floating point observation.
     ///
     /// @param name name of the observation
@@ -133,16 +151,15 @@ class StatsMgr : public boost::noncopyable {
     /// Samples older than duration will be discarded. This is time-constrained
     /// approach. For sample count constrained approach, see @ref
     /// setMaxSampleCount() below.
-    ///
+    /// Example:
+    /// To set a statistic to keep observations for the last 5 minutes, call:
+    /// setMaxSampleAge("incoming-packets", StatsDuration::minutes(5));
+    /// to revert statistic to a single value, call:
+    /// setMaxSampleAge("incoming-packets", StatsDuration:zero());
     ///
     /// @param name name of the observation
     /// @param duration determines maximum age of samples
     /// @return true if successful, false if there's no such statistic
-    /// Example:
-    /// To set a statistic to keep observations for the last 5 minutes, call:
-    /// setMaxSampleAge("incoming-packets", time_duration(0, 5, 0, 0));
-    /// to revert statistic to a single value, call:
-    /// setMaxSampleAge("incoming-packets", time_duration(0, 0, 0, 0));
     bool setMaxSampleAge(const std::string& name, const StatsDuration& duration);
 
     /// @brief Determines how many samples of a given statistic should be kept.
@@ -150,22 +167,47 @@ class StatsMgr : public boost::noncopyable {
     /// Specifies that statistic name should be stored not as single value, but
     /// rather as a set of values. In this form, at most max_samples will be kept.
     /// When adding max_samples + 1 sample, the oldest sample will be discarded.
-    ///
+    /// Example:
+    /// To set a statistic to keep the last 100 observations, call:
+    /// setMaxSampleCount("incoming-packets", 100);
     ///
     /// @param name name of the observation
     /// @param max_samples how many samples of a given statistic should be kept
     /// @return true if successful, false if there's no such statistic
-    /// Example:
-    /// To set a statistic to keep the last 100 observations, call:
-    /// setMaxSampleCount("incoming-packets", 100);
     bool setMaxSampleCount(const std::string& name, uint32_t max_samples);
 
     /// @brief Set duration limit for all collected statistics.
+    ///
+    /// @param duration determines maximum age of samples
     void setMaxSampleAgeAll(const StatsDuration& duration);
 
     /// @brief Set count limit for all collected statistics.
+    ///
+    /// @param max_samples how many samples of a given statistic should be kept
     void setMaxSampleCountAll(uint32_t max_samples);
 
+    /// @brief Set default duration limit.
+    ///
+    /// @param duration default maximum age of samples to keep
+    void setMaxSampleAgeDefault(const StatsDuration& duration);
+
+    /// @brief Set default count limit.
+    ///
+    /// @param max_samples default maximum number of samples to keep
+    /// (0 means to disable count limit and enable age limit)
+    void setMaxSampleCountDefault(uint32_t max_samples);
+
+    /// @brief Get default duration limit.
+    ///
+    /// @return default maximum age of samples to keep.
+    const StatsDuration& getMaxSampleAgeDefault() const;
+
+    /// @brief Get default count limit.
+    ///
+    /// @return default maximum number of samples to keep.
+    /// (0 means that count limit was disabled)
+    uint32_t getMaxSampleCountDefault() const;
+
     /// @}
 
     /// @defgroup consumer_methods Methods are used by data consumers.
@@ -178,6 +220,7 @@ class StatsMgr : public boost::noncopyable {
     ///
     /// This is a convenience function and is equivalent to setValue(name,
     /// neutral_value), where neutral_value is 0, 0.0 or "".
+    ///
     /// @param name name of the statistic to be reset.
     /// @return true if successful, false if there's no such statistic
     bool reset(const std::string& name);
@@ -192,6 +235,7 @@ class StatsMgr : public boost::noncopyable {
     void resetAll();
 
     /// @brief Removes all collected statistics.
+    /// @note This command was deprecated.
     void removeAll();
 
     /// @brief Returns size of specified statistic.
@@ -219,11 +263,23 @@ class StatsMgr : public boost::noncopyable {
 
     /// @brief Returns an observation.
     ///
-    /// Used in testing only. Production code should use @ref get() method.
+    /// Used in testing only. Production code should use @ref get() method
+    /// when the value is dereferenced.
+    /// Calls @ref getObservationInternal() method in a thread safe context.
+    ///
     /// @param name name of the statistic
     /// @return Pointer to the Observation object
     ObservationPtr getObservation(const std::string& name) const;
 
+    /// @brief Returns an observation in a thread safe context.
+    ///
+    /// Used in testing only. Production code should use @ref get() method
+    /// when the value is dereferenced. Should be called in a thread safe context.
+    ///
+    /// @param name name of the statistic
+    /// @return Pointer to the Observation object
+    ObservationPtr getObservationInternal(const std::string& name) const;
+
     /// @brief Generates statistic name in a given context
     ///
     /// Example:
@@ -309,7 +365,7 @@ class StatsMgr : public boost::noncopyable {
     /// @brief Handles statistic-sample-age-set command
     ///
     /// This method handles statistic-sample-age-set command,
-    /// which set max_sample_age_ limit of a given statistic
+    /// which sets max_sample_age_ limit of a given statistic
     /// and leaves max_sample_count_ disabled.
     /// It expects two parameters stored in params map:
     /// name: name of the statistic
@@ -331,7 +387,7 @@ class StatsMgr : public boost::noncopyable {
     /// @brief Handles statistic-sample-count-set command
     ///
     /// This method handles statistic-sample-count-set command,
-    /// which set max_sample_count_ limit of a given statistic
+    /// which sets max_sample_count_ limit of a given statistic
     /// and leaves max_sample_age_ disabled.
     /// It expects two parameters stored in params map:
     /// name: name of the statistic
@@ -376,6 +432,8 @@ class StatsMgr : public boost::noncopyable {
 
     /// @brief Handles statistic-remove-all command
     ///
+    /// @note The statistic-remove-all command was deprecated.
+    ///
     /// This method handles statistic-remove-all command, which removes all
     /// statistics. Params parameter is ignored.
     ///
@@ -389,7 +447,7 @@ class StatsMgr : public boost::noncopyable {
     /// @brief Handles statistic-sample-age-set-all command
     ///
     /// This method handles statistic-sample-age-set-all command,
-    /// which set max_sample_age_ limit to all statistics.
+    /// which sets max_sample_age_ limit to all statistics and the default.
     /// It expects one parameter stored in params map:
     /// duration: limit expressed as a number of seconds
     ///
@@ -398,37 +456,37 @@ class StatsMgr : public boost::noncopyable {
     ///     "duration": 1245
     /// }
     ///
-    /// @param name name of the command (ignored, should be "statistic-sample-age-set-all")
     /// @param params structure containing a map that contains "duration"
     /// @return answer confirming success of this operation
-    static isc::data::ConstElementPtr
-    statisticSetMaxSampleAgeAllHandler(const std::string& name,
-                                       const isc::data::ConstElementPtr& params);
+    isc::data::ConstElementPtr
+    statisticSetMaxSampleAgeAllHandler(const isc::data::ConstElementPtr& params);
 
     /// @brief Handles statistic-sample-count-set-all command
     ///
     /// This method handles statistic-sample-count-set-all command,
-    /// which set max_sample_count_ limit of all statistics.
+    /// which sets max_sample_count_ limit of all statistics and the default.
     /// It expects one parameter stored in params map:
     /// max-samples: count limit
+    /// The value 0 is out of range.
     ///
     /// Example params structure:
     /// {
     ///     "max-samples": 15
     /// }
     ///
-    /// @param name name of the command (ignored, should be "statistic-sample-count-set-all")
     /// @param params structure containing a map that contains "max-samples"
     /// @return answer confirming success of this operation
-    static isc::data::ConstElementPtr
-    statisticSetMaxSampleCountAllHandler(const std::string& name,
-                                         const isc::data::ConstElementPtr& params);
+    isc::data::ConstElementPtr
+    statisticSetMaxSampleCountAllHandler(const isc::data::ConstElementPtr& params);
 
     /// @}
 
 private:
 
+    /// @private
+
     /// @brief Private constructor.
+    ///
     /// StatsMgr is a singleton. It should be accessed using @ref instance
     /// method.
     StatsMgr();
@@ -447,14 +505,13 @@ private:
     /// @throw InvalidStatType is statistic exists and has a different type.
     template<typename DataType>
     void setValueInternal(const std::string& name, DataType value) {
-
         // If we want to log each observation, here would be the best place for it.
-        ObservationPtr stat = getObservation(name);
+        ObservationPtr stat = getObservationInternal(name);
         if (stat) {
             stat->setValue(value);
         } else {
             stat.reset(new Observation(name, value));
-            addObservation(stat);
+            addObservationInternal(stat);
         }
     }
 
@@ -472,14 +529,13 @@ private:
     /// @throw InvalidStatType is statistic exists and has a different type.
     template<typename DataType>
     void addValueInternal(const std::string& name, DataType value) {
-
         // If we want to log each observation, here would be the best place for it.
-        ObservationPtr existing = getObservation(name);
+        ObservationPtr existing = getObservationInternal(name);
         if (!existing) {
             // We tried to add to a non-existing statistic. We can recover from
             // that. Simply add the new incremental value as a new statistic and
             // we're done.
-            setValue(name, value);
+            setValueInternal(name, value);
             return;
         } else {
             // Let's hope it is of correct type. If not, the underlying
@@ -494,17 +550,189 @@ private:
     ///
     /// That's an utility method used by public @ref setValue() and
     /// @ref addValue() methods.
+    /// Calls @ref addObservationInternal() method in a thread safe context.
+    ///
     /// @param stat observation
     void addObservation(const ObservationPtr& stat);
 
+    /// @public
+
+    /// @brief Adds a new observation in a thread safe context.
+    ///
+    /// That's an utility method used by public @ref setValue() and
+    /// @ref addValue() methods.
+    /// Should be called in a thread safe context.
+    ///
+    /// @param stat observation
+    void addObservationInternal(const ObservationPtr& stat);
+
     /// @private
 
     /// @brief Tries to delete an observation.
     ///
+    /// Calls @ref deleteObservationInternal() method in a thread safe context.
+    ///
     /// @param name of the statistic to be deleted
     /// @return true if deleted, false if not found
     bool deleteObservation(const std::string& name);
 
+    /// @private
+
+    /// @brief Tries to delete an observation in a thread safe context.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @param name of the statistic to be deleted
+    /// @return true if deleted, false if not found
+    bool deleteObservationInternal(const std::string& name);
+
+    /// @private
+
+    /// @brief Determines maximum age of samples.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @param name name of the observation
+    /// @param duration determines maximum age of samples
+    /// @return true if successful, false if there's no such statistic
+    bool setMaxSampleAgeInternal(const std::string& name, const StatsDuration& duration);
+
+    /// @private
+
+    /// @brief Determines how many samples of a given statistic should be kept.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @param name name of the observation
+    /// @param max_samples how many samples of a given statistic should be kept
+    /// @return true if successful, false if there's no such statistic
+    bool setMaxSampleCountInternal(const std::string& name, uint32_t max_samples);
+
+    /// @private
+
+    /// @brief Set duration limit for all collected statistics.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @param duration determines maximum age of samples
+    void setMaxSampleAgeAllInternal(const StatsDuration& duration);
+
+    /// @private
+
+    /// @brief Set count limit for all collected statistics.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @param max_samples how many samples of a given statistic should be kept
+    void setMaxSampleCountAllInternal(uint32_t max_samples);
+
+    /// @private
+
+    /// @brief Set default duration limit.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @param duration default maximum age of samples to keep.
+    void setMaxSampleAgeDefaultInternal(const StatsDuration& duration);
+
+    /// @brief Set default count limit.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @param max_samples default maximum number of samples to keep.
+    /// (0 means to disable count limit and enable age limit)
+    void setMaxSampleCountDefaultInternal(uint32_t max_samples);
+
+    /// @private
+
+    /// @brief Get default duration limit.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @return default maximum age of samples to keep.
+    const StatsDuration& getMaxSampleAgeDefaultInternal() const;
+
+    /// @brief Get default count limit.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @return default maximum number of samples to keep.
+    /// (0 means that count limit was disabled)
+    uint32_t getMaxSampleCountDefaultInternal() const;
+
+    /// @private
+
+    /// @brief Resets specified statistic.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @param name name of the statistic to be reset.
+    /// @return true if successful, false if there's no such statistic
+    bool resetInternal(const std::string& name);
+
+    /// @private
+
+    /// @brief Removes specified statistic.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @param name name of the statistic to be removed.
+    /// @return true if successful, false if there's no such statistic
+    bool delInternal(const std::string& name);
+
+    /// @private
+
+    /// @brief Resets all collected statistics back to zero.
+    ///
+    /// Should be called in a thread safe context.
+    void resetAllInternal();
+
+    /// @private
+
+    /// @brief Removes all collected statistics.
+    ///
+    /// Should be called in a thread safe context.
+    void removeAllInternal();
+
+    /// @private
+
+    /// @brief Returns size of specified statistic.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @param name name of the statistic which size should be return.
+    /// @return size of specified statistic, 0 means lack of given statistic.
+    size_t getSizeInternal(const std::string& name) const;
+
+    /// @private
+
+    /// @brief Returns number of available statistics.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @return number of recorded statistics.
+    size_t countInternal() const;
+
+    /// @private
+
+    /// @brief Returns a single statistic as a JSON structure.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @return JSON structures representing a single statistic
+    isc::data::ConstElementPtr getInternal(const std::string& name) const;
+
+    /// @private
+
+    /// @brief Returns all statistics as a JSON structure.
+    ///
+    /// Should be called in a thread safe context.
+    ///
+    /// @return JSON structures representing all statistics
+    isc::data::ConstElementPtr getAllInternal() const;
+
+    /// @private
+
     /// @brief Utility method that attempts to extract statistic name
     ///
     /// This method attempts to extract statistic name from the params
@@ -521,6 +749,8 @@ private:
                             std::string& name,
                             std::string& reason);
 
+    /// @private
+
     /// @brief Utility method that attempts to extract duration limit for
     /// a given statistic
     ///
@@ -541,6 +771,8 @@ private:
                                 StatsDuration& duration,
                                 std::string& reason);
 
+    /// @private
+
     /// @brief Utility method that attempts to extract count limit for
     /// a given statistic
     ///
@@ -560,11 +792,14 @@ private:
                                   uint32_t& max_samples,
                                   std::string& reason);
 
-    // This is a global context. All statistics will initially be stored here.
+    /// @brief This is a global context. All statistics will initially be stored here.
     StatContextPtr global_;
+
+    /// @brief The mutex used to protect internal state.
+    const boost::scoped_ptr<std::mutex> mutex_;
 };
 
-};
-};
+}  // namespace stats
+}  // namespace isc
 
 #endif // STATS_MGR
