@@ -1,4 +1,4 @@
-// Copyright (C) 2022-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2022-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -33,19 +33,9 @@ namespace {
 /// @brief IP address to which service is bound.
 const std::string SERVER_ADDRESS = "127.0.0.1";
 
-/// @brief IPv6 address to whch service is bound.
-const std::string IPV6_SERVER_ADDRESS = "::1";
-
 /// @brief Port number to which service is bound.
 const unsigned short SERVER_PORT = 18123;
 
-/// @brief Request Timeout used in most of the tests (ms).
-const long REQUEST_TIMEOUT = 10000;
-
-/// @brief Connection idle timeout used in tests where idle connections
-/// are tested (ms).
-const long SHORT_REQUEST_TIMEOUT = 200;
-
 /// @brief Connection idle timeout used in most of the tests (ms).
 const long IDLE_TIMEOUT = 10000;
 
@@ -64,7 +54,7 @@ public:
     ///
     /// Starts test timer which detects timeouts.
     TcpListenerTest()
-        : io_service_(), test_timer_(io_service_),
+        : io_service_(new IOService()), test_timer_(io_service_),
           run_io_service_timer_(io_service_),
           clients_(), clients_done_(0) {
         test_timer_.setup(std::bind(&TcpListenerTest::timeoutHandler, this, true),
@@ -76,9 +66,12 @@ public:
     ///
     /// Removes active clients.
     virtual ~TcpListenerTest() {
-        for (auto client : clients_) {
+        for (auto const& client : clients_) {
             client->close();
         }
+
+        test_timer_.cancel();
+        io_service_->stopAndPoll();
     }
 
     /// @brief Create a new client.
@@ -129,7 +122,7 @@ public:
         if (fail_on_timeout) {
             ADD_FAILURE() << "Timeout occurred while running the test!";
         }
-        io_service_.stop();
+        io_service_->stop();
     }
 
     /// @brief Callback function each client invokes when done.
@@ -141,7 +134,7 @@ public:
         ++clients_done_;
         if (clients_done_ >= clients_.size()) {
             // They're all done or dead. Stop the service.
-            io_service_.stop();
+            io_service_->stop();
         }
     }
 
@@ -150,7 +143,8 @@ public:
     /// @param timeout Optional value specifying for how long the io service
     /// should be ran.
     void runIOService(long timeout = 0) {
-        io_service_.get_io_service().reset();
+        io_service_->stop();
+        io_service_->restart();
 
         if (timeout > 0) {
             run_io_service_timer_.setup(std::bind(&TcpListenerTest::timeoutHandler,
@@ -158,9 +152,8 @@ public:
                                         timeout,
                                         IntervalTimer::ONE_SHOT);
         }
-        io_service_.run();
-        io_service_.get_io_service().reset();
-        io_service_.poll();
+        io_service_->run();
+        io_service_->stopAndPoll(false);
     }
 
     /// @brief Filter that denies every other connection.
@@ -182,7 +175,7 @@ public:
     }
 
     /// @brief IO service used in the tests.
-    IOService io_service_;
+    IOServicePtr io_service_;
 
     /// @brief Asynchronous timer service to detect timeouts.
     IntervalTimer test_timer_;
@@ -234,7 +227,7 @@ TEST_F(TcpListenerTest, listen) {
     ASSERT_EQ(expected_entries, listener.audit_trail_->getConnectionTrail(1));
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 // This test verifies that a TCP connection can receive a complete
@@ -266,7 +259,7 @@ TEST_F(TcpListenerTest, splitReads) {
     EXPECT_FALSE(client->expectedEof());
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 // This test verifies that a TCP connection can be established and used to
@@ -295,7 +288,7 @@ TEST_F(TcpListenerTest, idleTimeoutTest) {
     EXPECT_TRUE(client->expectedEof());
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 TEST_F(TcpListenerTest, multipleClientsListen) {
@@ -319,7 +312,7 @@ TEST_F(TcpListenerTest, multipleClientsListen) {
     ASSERT_EQ(num_clients, clients_.size());
 
     size_t connection_id = 1;
-    for (auto client : clients_) {
+    for (auto const& client : clients_) {
         EXPECT_TRUE(client->receiveDone());
         EXPECT_FALSE(client->expectedEof());
         // Create the list of expected entries.
@@ -329,13 +322,13 @@ TEST_F(TcpListenerTest, multipleClientsListen) {
         };
 
         // Fetch the entries for this connection.
-        auto entries = listener.audit_trail_->getConnectionTrail(connection_id);
+        auto const& entries = listener.audit_trail_->getConnectionTrail(connection_id);
         ASSERT_EQ(expected_entries, entries);
         ++connection_id;
     }
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 // Verify that the listener handles multiple requests for multiple
@@ -363,7 +356,7 @@ TEST_F(TcpListenerTest, multipleRequetsPerClients) {
     std::list<std::string>expected_responses{ "echo one", "echo two",
                                               "echo three", "good bye"};
     size_t connection_id = 1;
-    for (auto client : clients_) {
+    for (auto const& client : clients_) {
         EXPECT_TRUE(client->receiveDone());
         EXPECT_FALSE(client->expectedEof());
         EXPECT_EQ(expected_responses, client->getResponses());
@@ -382,13 +375,13 @@ TEST_F(TcpListenerTest, multipleRequetsPerClients) {
         };
 
         // Fetch the entries for this connection.
-        auto entries = listener.audit_trail_->getConnectionTrail(connection_id);
+        auto const& entries = listener.audit_trail_->getConnectionTrail(connection_id);
         ASSERT_EQ(expected_entries, entries);
         ++connection_id;
     }
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 // Verify that connection filtering can eliminate specific connections.
@@ -420,7 +413,7 @@ TEST_F(TcpListenerTest, filterClientsTest) {
     ASSERT_EQ(num_clients, clients_.size());
 
     size_t i = 0;
-    for (auto client : clients_) {
+    for (auto const& client : clients_) {
         if (i % 2 == 0) {
             // These clients should have been accepted and received responses.
             EXPECT_TRUE(client->receiveDone());
@@ -433,7 +426,7 @@ TEST_F(TcpListenerTest, filterClientsTest) {
                 { i+1, AuditEntry::OUTBOUND, "good bye" }
             };
 
-            auto entries = listener.audit_trail_->getConnectionTrail(i+1);
+            auto const& entries = listener.audit_trail_->getConnectionTrail(i+1);
             ASSERT_EQ(expected_entries, entries);
 
         } else {
@@ -442,7 +435,7 @@ TEST_F(TcpListenerTest, filterClientsTest) {
             EXPECT_TRUE(client->expectedEof());
 
             // Verify connection recorded no audit entries.
-            auto entries = listener.audit_trail_->getConnectionTrail(i+1);
+            auto const& entries = listener.audit_trail_->getConnectionTrail(i+1);
             ASSERT_EQ(entries.size(), 0);
         }
 
@@ -450,7 +443,7 @@ TEST_F(TcpListenerTest, filterClientsTest) {
     }
 
     listener.stop();
-    io_service_.poll();
+    io_service_->poll();
 }
 
 // Exercises TcpStreamRequest::postBuffer() through various
@@ -561,11 +554,11 @@ TEST(TcpStreamRequst, postBufferTest) {
         }
     }
 
-    for (auto scenario : scenarios ) {
+    for (auto const& scenario : scenarios ) {
         SCOPED_TRACE(scenario.desc_);
         std::list<TcpStreamRequestPtr> requests;
         TcpStreamRequestPtr request;
-        for (auto input_buf : scenario.input_buffers_) {
+        for (auto const& input_buf : scenario.input_buffers_) {
             // Copy the input buffer.
             std::vector<uint8_t> buf = input_buf;
 
@@ -593,7 +586,7 @@ TEST(TcpStreamRequst, postBufferTest) {
 
         ASSERT_EQ(requests.size(), scenario.expected_strings_.size());
         auto exp_string = scenario.expected_strings_.begin();
-        for (auto recvd_request : requests) {
+        for (auto const& recvd_request : requests) {
             ASSERT_NO_THROW(recvd_request->unpack());
             EXPECT_EQ(*exp_string++, recvd_request->getRequestString());
         }
