@@ -1,9 +1,11 @@
-// Copyright (C) 2012-2015 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
+#include <config.h>
+
 #include <util/unittests/wiredata.h>
 
 #include <gtest/gtest.h>
@@ -19,10 +21,8 @@ namespace unittests {
 
 void
 matchWireData(const void* expected_data, size_t expected_len,
-              const void* actual_data, size_t actual_len)
-{
+              const void* actual_data, size_t actual_len) {
     const size_t cmplen = std::min(expected_len, actual_len);
-
     for (size_t i = 0; i < cmplen; ++i) {
         const int ebyte = static_cast<const uint8_t*>(expected_data)[i];
         const int abyte = static_cast<const uint8_t*>(actual_data)[i];
