@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2022 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -6,11 +6,11 @@
 
 #include <config.h>
 
+#include <gtest/gtest.h>
+
+#include <yang/tests/sysrepo_setup.h>
 #include <yang/translator_subnet.h>
 #include <yang/yang_models.h>
-#include <yang/tests/sysrepo_setup.h>
-
-#include <gtest/gtest.h>
 
 using namespace std;
 using namespace isc;
@@ -28,30 +28,29 @@ extern char const subnet_list[] = "subnet list";
 class TranslatorSubnetsTestKeaV4 :
     public GenericTranslatorTest<subnet_list, TranslatorSubnets> {
 public:
-
-    /// Constructor.
+    /// @brief Constructor
     TranslatorSubnetsTestKeaV4() {
         model_ = KEA_DHCP4_SERVER;
     }
-};
+};  // TranslatorSubnetsTestKeaV4
+
 class TranslatorSubnetsTestKeaV6 :
     public GenericTranslatorTest<subnet_list, TranslatorSubnets> {
 public:
-
-    /// Constructor.
+    /// @brief Constructor
     TranslatorSubnetsTestKeaV6() {
         model_ = KEA_DHCP6_SERVER;
     }
-};
+};  // TranslatorSubnetsTestKeaV6
+
 class TranslatorSubnetsTestIetfV6 :
     public GenericTranslatorTest<subnet_list, TranslatorSubnets> {
 public:
-
-    /// Constructor.
+    /// @brief Constructor
     TranslatorSubnetsTestIetfV6() {
         model_ = IETF_DHCPV6_SERVER;
     }
-};
+};  // TranslatorSubnetsTestIetfV6
 
 // This test verifies that an empty subnet list can be properly
 // translated from YANG to JSON using IETF model.
@@ -60,7 +59,7 @@ TEST_F(TranslatorSubnetsTestIetfV6, getEmptyIetf) {
     const string& xpath =
         "/ietf-dhcpv6-server:server/server-config/network-ranges";
     ConstElementPtr subnets;
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_FALSE(subnets);
 }
 
@@ -70,7 +69,7 @@ TEST_F(TranslatorSubnetsTestKeaV6, getEmptyKea) {
     // Get the subnet list and check if it is empty.
     const string& xpath = "/kea-dhcp6-server:config";
     ConstElementPtr subnets;
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_FALSE(subnets);
 }
 
@@ -81,13 +80,14 @@ TEST_F(TranslatorSubnetsTestIetfV6, getIetf) {
     const string& xpath =
         "/ietf-dhcpv6-server:server/server-config/network-ranges";
     const string& xsub = xpath + "/network-range[network-range-id='111']";
-    S_Val v_subnet(new Val("2001:db8::/48", SR_STRING_T));
+    string const v_subnet("2001:db8::/48");
     const string& xsubnet = xsub + "/network-prefix";
-    EXPECT_NO_THROW(sess_->set_item(xsubnet.c_str(), v_subnet));
+    EXPECT_NO_THROW_LOG(sess_->setItem(xsubnet, v_subnet));
+    sess_->applyChanges();
 
     // Get the subnet.
     ConstElementPtr subnet;
-    EXPECT_NO_THROW(subnet = t_obj_->getSubnet(xsub));
+    EXPECT_NO_THROW_LOG(subnet = translator_->getSubnetFromAbsoluteXpath(xsub));
     ASSERT_TRUE(subnet);
     EXPECT_EQ("{ \"id\": 111, "
               "\"subnet\": \"2001:db8::/48\" }",
@@ -95,7 +95,7 @@ TEST_F(TranslatorSubnetsTestIetfV6, getIetf) {
 
     // Get the subnet list and check if the subnet is in it.
     ConstElementPtr subnets;
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_TRUE(subnets);
     ASSERT_EQ(Element::list, subnets->getType());
     ASSERT_EQ(1, subnets->size());
@@ -109,22 +109,23 @@ TEST_F(TranslatorSubnetsTestKeaV6, getKea) {
     // Create the subnet 2001:db8::/48 #111.
     const string& xpath = "/kea-dhcp6-server:config";
     const string& xsub = xpath + "/subnet6[id='111']";
-    S_Val v_subnet(new Val("2001:db8::/48", SR_STRING_T));
+    string const v_subnet("2001:db8::/48");
     const string& xsubnet = xsub + "/subnet";
-    EXPECT_NO_THROW(sess_->set_item(xsubnet.c_str(), v_subnet));
+    EXPECT_NO_THROW_LOG(sess_->setItem(xsubnet, v_subnet));
+    sess_->applyChanges();
 
     // Get the subnet.
     ConstElementPtr subnet;
-    EXPECT_NO_THROW(subnet = t_obj_->getSubnet(xsub));
+    EXPECT_NO_THROW_LOG(subnet = translator_->getSubnetFromAbsoluteXpath(xsub));
     ASSERT_TRUE(subnet);
     ElementPtr expected = Element::createMap();
     expected->set("id", Element::create(111));
-    expected->set("subnet", Element::create(string("2001:db8::/48")));
+    expected->set("subnet", Element::create("2001:db8::/48"));
     EXPECT_TRUE(expected->equals(*subnet));
 
     // Get the subnet list and check if the subnet is in it.
     ConstElementPtr subnets;
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_TRUE(subnets);
     ASSERT_EQ(Element::list, subnets->getType());
     ASSERT_EQ(1, subnets->size());
@@ -138,24 +139,27 @@ TEST_F(TranslatorSubnetsTestIetfV6, getPoolsIetf) {
     const string& xpath =
         "/ietf-dhcpv6-server:server/server-config/network-ranges";
     const string& xsub = xpath + "/network-range[network-range-id='111']";
-    S_Val v_subnet(new Val("2001:db8::/48", SR_STRING_T));
+    string const v_subnet("2001:db8::/48");
     const string& xsubnet = xsub + "/network-prefix";
-    EXPECT_NO_THROW(sess_->set_item(xsubnet.c_str(), v_subnet));
+    EXPECT_NO_THROW_LOG(sess_->setItem(xsubnet, v_subnet));
+    sess_->applyChanges();
 
     // Create the pool 2001:db8::1:0/112 #1.
     const string& xpool = xsub + "/address-pools";
     const string& prefix1 = xpool + "/address-pool[pool-id='1']/pool-prefix";
-    S_Val s_pool1(new Val("2001:db8::1:0/112"));
-    EXPECT_NO_THROW(sess_->set_item(prefix1.c_str(), s_pool1));
+    string const s_pool1("2001:db8::1:0/112");
+    EXPECT_NO_THROW_LOG(sess_->setItem(prefix1, s_pool1));
+    sess_->applyChanges();
 
     // Create the pool 2001:db8::2:0/112 #2.
     const string& prefix2 = xpool + "/address-pool[pool-id='2']/pool-prefix";
-    S_Val s_pool2(new Val("2001:db8::2:0/112"));
-    EXPECT_NO_THROW(sess_->set_item(prefix2.c_str(), s_pool2));
+    string const s_pool2("2001:db8::2:0/112");
+    EXPECT_NO_THROW_LOG(sess_->setItem(prefix2, s_pool2));
+    sess_->applyChanges();
 
     // Get the subnet.
     ConstElementPtr subnet;
-    EXPECT_NO_THROW(subnet = t_obj_->getSubnet(xsub));
+    EXPECT_NO_THROW_LOG(subnet = translator_->getSubnetFromAbsoluteXpath(xsub));
     ASSERT_TRUE(subnet);
     string expected =
         "{\n"
@@ -174,7 +178,7 @@ TEST_F(TranslatorSubnetsTestIetfV6, getPoolsIetf) {
 
     // Get the subnet list and check if the subnet is in it.
     ConstElementPtr subnets;
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_TRUE(subnets);
     ASSERT_EQ(Element::list, subnets->getType());
     ASSERT_EQ(1, subnets->size());
@@ -187,25 +191,27 @@ TEST_F(TranslatorSubnetsTestKeaV6, getPoolsKea) {
     // Create the subnet 2001:db8::/48 #111.
     const string& xpath = "/kea-dhcp6-server:config";
     const string& xsub = xpath + "/subnet6[id='111']";
-    S_Val v_subnet(new Val("2001:db8::/48", SR_STRING_T));
+    string const v_subnet("2001:db8::/48");
     const string& xsubnet = xsub + "/subnet";
-    EXPECT_NO_THROW(sess_->set_item(xsubnet.c_str(), v_subnet));
+    EXPECT_NO_THROW_LOG(sess_->setItem(xsubnet, v_subnet));
+    sess_->applyChanges();
 
     // Create the pool 2001:db8::1:0/112.
     const string& prefix1 = xsub + "/pool[start-address='2001:db8::1:0']" +
         "[end-address='2001:db8::1:ffff']/prefix";
-    S_Val s_pool1(new Val("2001:db8::1:0/112", SR_STRING_T));
-    EXPECT_NO_THROW(sess_->set_item(prefix1.c_str(), s_pool1));
+    string const s_pool1("2001:db8::1:0/112");
+    EXPECT_NO_THROW_LOG(sess_->setItem(prefix1, s_pool1));
+    sess_->applyChanges();
 
     // Create the pool 2001:db8::2:0/112.
     const string& prefix2 = xsub + "/pool[start-address='2001:db8::2:0']" +
         "[end-address='2001:db8::2:ffff']";
-    S_Val s_pool2;
-    EXPECT_NO_THROW(sess_->set_item(prefix2.c_str(), s_pool2));
+    EXPECT_NO_THROW_LOG(sess_->setItem(prefix2, nullopt));
+    sess_->applyChanges();
 
     // Get the subnet.
     ConstElementPtr subnet;
-    EXPECT_NO_THROW(subnet = t_obj_->getSubnet(xsub));
+    EXPECT_NO_THROW_LOG(subnet = translator_->getSubnetFromAbsoluteXpath(xsub));
     ASSERT_TRUE(subnet);
     string expected =
         "{\n"
@@ -224,7 +230,7 @@ TEST_F(TranslatorSubnetsTestKeaV6, getPoolsKea) {
 
     // Get the subnet list and check if the subnet is in it.
     ConstElementPtr subnets;
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_TRUE(subnets);
     ASSERT_EQ(Element::list, subnets->getType());
     ASSERT_EQ(1, subnets->size());
@@ -238,11 +244,11 @@ TEST_F(TranslatorSubnetsTestIetfV6, setEmptyIetf) {
     const string& xpath =
         "/ietf-dhcpv6-server:server/server-config/network-ranges";
     ConstElementPtr subnets = Element::createList();
-    EXPECT_NO_THROW(t_obj_->setSubnets(xpath, subnets));
+    EXPECT_NO_THROW_LOG(translator_->setSubnets(xpath, subnets));
 
     // Get it back.
     subnets.reset();
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_FALSE(subnets);
 }
 
@@ -252,11 +258,11 @@ TEST_F(TranslatorSubnetsTestKeaV4, setEmptyKea) {
     // Set empty list.
     const string& xpath = "/kea-dhcp4-server:config";
     ElementPtr subnets = Element::createList();
-    EXPECT_NO_THROW(t_obj_->setSubnets(xpath, subnets));
+    EXPECT_NO_THROW_LOG(translator_->setSubnets(xpath, subnets));
 
     // Get it back.
     subnets.reset();
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_FALSE(subnets);
 }
 
@@ -268,14 +274,14 @@ TEST_F(TranslatorSubnetsTestIetfV6, setIetf) {
         "/ietf-dhcpv6-server:server/server-config/network-ranges";
     ElementPtr subnets = Element::createList();
     ElementPtr subnet = Element::createMap();
-    subnet->set("subnet", Element::create(string("2001:db8::/48")));
+    subnet->set("subnet", Element::create("2001:db8::/48"));
     subnet->set("id", Element::create(123));
     subnets->add(subnet);
-    EXPECT_NO_THROW(t_obj_->setSubnets(xpath, subnets));
+    EXPECT_NO_THROW_LOG(translator_->setSubnets(xpath, subnets));
 
     // Get it back.
     subnets.reset();
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_TRUE(subnets);
     ASSERT_EQ(Element::list, subnets->getType());
     ASSERT_EQ(1, subnets->size());
@@ -289,21 +295,18 @@ TEST_F(TranslatorSubnetsTestKeaV4, setKea) {
     const string& xpath = "/kea-dhcp4-server:config";
     ElementPtr subnets = Element::createList();
     ElementPtr subnet = Element::createMap();
-    subnet->set("subnet", Element::create(string("10.0.1.0/24")));
+    subnet->set("subnet", Element::create("10.0.1.0/24"));
     subnet->set("id", Element::create(123));
     subnets->add(subnet);
-    EXPECT_NO_THROW(t_obj_->setSubnets(xpath, subnets));
+    EXPECT_NO_THROW_LOG(translator_->setSubnets(xpath, subnets));
 
     // Get it back.
     subnets.reset();
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_TRUE(subnets);
     ASSERT_EQ(Element::list, subnets->getType());
     ASSERT_EQ(1, subnets->size());
     EXPECT_TRUE(subnet->equals(*subnets->get(0)));
-
-    // Check it validates.
-    EXPECT_NO_THROW(sess_->validate());
 }
 
 // This test verifies that one subnet with two pools can be properly
@@ -314,26 +317,26 @@ TEST_F(TranslatorSubnetsTestIetfV6, setTwoIetf) {
         "/ietf-dhcpv6-server:server/server-config/network-ranges";
     ElementPtr subnets = Element::createList();
     ElementPtr subnet = Element::createMap();
-    subnet->set("subnet", Element::create(string("2001:db8::/48")));
+    subnet->set("subnet", Element::create("2001:db8::/48"));
     subnet->set("id", Element::create(123));
 
     // Add two pools.
     ElementPtr pools = Element::createList();
     ElementPtr pool1 = Element::createMap();
-    pool1->set("pool", Element::create(string("2001:db8::1:0/112")));
+    pool1->set("pool", Element::create("2001:db8::1:0/112"));
     pools->add(pool1);
     ElementPtr pool2 = Element::createMap();
-    pool2->set("pool", Element::create(string("2001:db8::2:0/112")));
+    pool2->set("pool", Element::create("2001:db8::2:0/112"));
     pools->add(pool2);
     subnet->set("pools", pools);
 
     // Add the subnet.
     subnets->add(subnet);
-    EXPECT_NO_THROW(t_obj_->setSubnets(xpath, subnets));
+    EXPECT_NO_THROW_LOG(translator_->setSubnets(xpath, subnets));
 
     // Get it back.
     subnets.reset();
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_TRUE(subnets);
     ASSERT_EQ(Element::list, subnets->getType());
     ASSERT_EQ(1, subnets->size());
@@ -347,33 +350,30 @@ TEST_F(TranslatorSubnetsTestKeaV4, setTwoKea) {
     const string& xpath = "/kea-dhcp4-server:config";
     ElementPtr subnets = Element::createList();
     ElementPtr subnet = Element::createMap();
-    subnet->set("subnet", Element::create(string("10.0.1.0/24")));
+    subnet->set("subnet", Element::create("10.0.1.0/24"));
     subnet->set("id", Element::create(123));
 
     // Add two pools.
     ElementPtr pools = Element::createList();
     ElementPtr pool1 = Element::createMap();
-    pool1->set("pool", Element::create(string("10.0.1.0/28")));
+    pool1->set("pool", Element::create("10.0.1.0/28"));
     pools->add(pool1);
     ElementPtr pool2 = Element::createMap();
-    pool2->set("pool", Element::create(string("10.0.1.200 - 10.0.1.222")));
+    pool2->set("pool", Element::create("10.0.1.200 - 10.0.1.222"));
     pools->add(pool2);
     subnet->set("pools", pools);
 
     // Add the subnet.
     subnets->add(subnet);
-    EXPECT_NO_THROW(t_obj_->setSubnets(xpath, subnets));
+    EXPECT_NO_THROW_LOG(translator_->setSubnets(xpath, subnets));
 
     // Get it back.
     subnets.reset();
-    EXPECT_NO_THROW(subnets = t_obj_->getSubnets(xpath));
+    EXPECT_NO_THROW_LOG(subnets = translator_->getSubnetsFromAbsoluteXpath(xpath));
     ASSERT_TRUE(subnets);
     ASSERT_EQ(Element::list, subnets->getType());
     ASSERT_EQ(1, subnets->size());
     EXPECT_TRUE(subnet->equals(*subnets->get(0)));
-
-    // Check it validates.
-    EXPECT_NO_THROW(sess_->validate());
 }
 
 }  // namespace
